```@meta
EditURL = "https://github.com/maartenvd/MPSKit.jl/examples/quantum1d/4.xxz-heisenberg/main.jl"
```

[![](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/maartenvd/MPSKit.jl/gh-pages?filepath=dev/examples/quantum1d/4.xxz-heisenberg/main.ipynb)
[![](https://img.shields.io/badge/show-nbviewer-579ACA.svg)](https://nbviewer.jupyter.org/github/maartenvd/MPSKit.jl/blob/gh-pages/dev/examples/quantum1d/4.xxz-heisenberg/main.ipynb)
[![](https://img.shields.io/badge/download-project-orange)](https://minhaskamal.github.io/DownGit/#/home?url=https://github.com/maartenvd/MPSKit.jl/examples/tree/gh-pages/dev/examples/quantum1d/4.xxz-heisenberg)

# The XXZ model

In this file we will give step by step instructions on how to analyze the spin 1/2 XXZ model.
The necessary packages to follow this tutorial are:

````julia
using MPSKit, MPSKitModels, TensorKit, Plots
import TensorOperations; TensorOperations.disable_cache(); # hide
````

## Failure

First we should define the hamiltonian we want to work with.
Then we specify an initial guess, which we then further optimize.
Working directly in the thermodynamic limit, this is achieved as follows:

````julia
H = heisenberg_XXX(; spin=1//2);
````

We then need an intial state, which we shall later optimize. In this example we work directly in the thermodynamic limit.

````julia
random_data = TensorMap(rand, ComplexF64, ℂ^20 * ℂ^2, ℂ^20);
state = InfiniteMPS([random_data]);
````

The groundstate can then be found by calling `find_groundstate`.

````julia
groundstate, cache, delta = find_groundstate(state, H, VUMPS());
````

````
[ Info: vumps @iteration 1 galerkin = 0.0019242263942779228
[ Info: vumps @iteration 2 galerkin = 0.5067408588166973
[ Info: vumps @iteration 3 galerkin = 0.5474972759534885
[ Info: vumps @iteration 4 galerkin = 0.4168154015411327
[ Info: vumps @iteration 5 galerkin = 0.4806893124927422
[ Info: vumps @iteration 6 galerkin = 0.581849808090621
[ Info: vumps @iteration 7 galerkin = 0.4629065039439779
[ Info: vumps @iteration 8 galerkin = 0.5357623441824556
[ Info: vumps @iteration 9 galerkin = 0.621157091706479
[ Info: vumps @iteration 10 galerkin = 0.47106200621980143
[ Info: vumps @iteration 11 galerkin = 0.5088153680821039
[ Info: vumps @iteration 12 galerkin = 0.5738407270229899
[ Info: vumps @iteration 13 galerkin = 0.5338972456645936
[ Info: vumps @iteration 14 galerkin = 0.46538664026783766
[ Info: vumps @iteration 15 galerkin = 0.5440680638307281
[ Info: vumps @iteration 16 galerkin = 0.43664605051192157
[ Info: vumps @iteration 17 galerkin = 0.44872729654452964
[ Info: vumps @iteration 18 galerkin = 0.560666581968847
[ Info: vumps @iteration 19 galerkin = 0.40516717311961686
[ Info: vumps @iteration 20 galerkin = 0.4344568164411861
[ Info: vumps @iteration 21 galerkin = 0.4746888593385685
[ Info: vumps @iteration 22 galerkin = 0.454325637132033
[ Info: vumps @iteration 23 galerkin = 0.45663946762746405
[ Info: vumps @iteration 24 galerkin = 0.44678438312899066
[ Info: vumps @iteration 25 galerkin = 0.519279346766618
[ Info: vumps @iteration 26 galerkin = 0.4741741271215243
[ Info: vumps @iteration 27 galerkin = 0.6346658975680737
[ Info: vumps @iteration 28 galerkin = 0.5488227304972035
[ Info: vumps @iteration 29 galerkin = 0.48718109181985414
[ Info: vumps @iteration 30 galerkin = 0.42106606686320575
[ Info: vumps @iteration 31 galerkin = 0.4916043811743643
[ Info: vumps @iteration 32 galerkin = 0.47282866401630097
[ Info: vumps @iteration 33 galerkin = 0.41323715336460665
[ Info: vumps @iteration 34 galerkin = 0.523555714183004
[ Info: vumps @iteration 35 galerkin = 0.4634575464919588
[ Info: vumps @iteration 36 galerkin = 0.41612706437218766
[ Info: vumps @iteration 37 galerkin = 0.5540109038424794
[ Info: vumps @iteration 38 galerkin = 0.4870005216688081
[ Info: vumps @iteration 39 galerkin = 0.4189422149322912
[ Info: vumps @iteration 40 galerkin = 0.32011796266631437
[ Info: vumps @iteration 41 galerkin = 0.34741566657561407
[ Info: vumps @iteration 42 galerkin = 0.5646493177482353
[ Info: vumps @iteration 43 galerkin = 0.5551031905049472
[ Info: vumps @iteration 44 galerkin = 0.5070948102817086
[ Info: vumps @iteration 45 galerkin = 0.4797861812514866
[ Info: vumps @iteration 46 galerkin = 0.49834550554002255
[ Info: vumps @iteration 47 galerkin = 0.5930542084415547
[ Info: vumps @iteration 48 galerkin = 0.4754198543444197
[ Info: vumps @iteration 49 galerkin = 0.41777692435301345
[ Info: vumps @iteration 50 galerkin = 0.5090230593612637
[ Info: vumps @iteration 51 galerkin = 0.5550718125714121
[ Info: vumps @iteration 52 galerkin = 0.51549084198176
[ Info: vumps @iteration 53 galerkin = 0.5909627471437727
[ Info: vumps @iteration 54 galerkin = 0.3955611770984787
[ Info: vumps @iteration 55 galerkin = 0.23872379725266638
[ Info: vumps @iteration 56 galerkin = 0.39046712938831485
[ Info: vumps @iteration 57 galerkin = 0.459915679596779
[ Info: vumps @iteration 58 galerkin = 0.4579779170412874
[ Info: vumps @iteration 59 galerkin = 0.43040630841660293
[ Info: vumps @iteration 60 galerkin = 0.5111383749627532
[ Info: vumps @iteration 61 galerkin = 0.5476595214667267
[ Info: vumps @iteration 62 galerkin = 0.4068939862957921
[ Info: vumps @iteration 63 galerkin = 0.28134856834864236
[ Info: vumps @iteration 64 galerkin = 0.5161588403489049
[ Info: vumps @iteration 65 galerkin = 0.6258917364786235
[ Info: vumps @iteration 66 galerkin = 0.5665186736820358
[ Info: vumps @iteration 67 galerkin = 0.4890232677251687
[ Info: vumps @iteration 68 galerkin = 0.47998319188425204
[ Info: vumps @iteration 69 galerkin = 0.5243729491394613
[ Info: vumps @iteration 70 galerkin = 0.25756795354318657
[ Info: vumps @iteration 71 galerkin = 0.5009644474658383
[ Info: vumps @iteration 72 galerkin = 0.5695635747050043
[ Info: vumps @iteration 73 galerkin = 0.5239053090221844
[ Info: vumps @iteration 74 galerkin = 0.4007689121201031
[ Info: vumps @iteration 75 galerkin = 0.4981839423126167
[ Info: vumps @iteration 76 galerkin = 0.5483014123187407
[ Info: vumps @iteration 77 galerkin = 0.5643096582419224
[ Info: vumps @iteration 78 galerkin = 0.5497348778472185
[ Info: vumps @iteration 79 galerkin = 0.5802458428449252
[ Info: vumps @iteration 80 galerkin = 0.508357308852087
[ Info: vumps @iteration 81 galerkin = 0.5069715865339941
[ Info: vumps @iteration 82 galerkin = 0.5391717740650553
[ Info: vumps @iteration 83 galerkin = 0.5064339702727855
[ Info: vumps @iteration 84 galerkin = 0.5295881240360713
[ Info: vumps @iteration 85 galerkin = 0.5123642367111289
[ Info: vumps @iteration 86 galerkin = 0.48314535660787217
[ Info: vumps @iteration 87 galerkin = 0.354731077934103
[ Info: vumps @iteration 88 galerkin = 0.47668228966147763
[ Info: vumps @iteration 89 galerkin = 0.5791799213636952
[ Info: vumps @iteration 90 galerkin = 0.5578566881086952
[ Info: vumps @iteration 91 galerkin = 0.6407042924739444
[ Info: vumps @iteration 92 galerkin = 0.533444142639943
[ Info: vumps @iteration 93 galerkin = 0.49484427573093387
[ Info: vumps @iteration 94 galerkin = 0.523533421178115
[ Info: vumps @iteration 95 galerkin = 0.41048138655493355
[ Info: vumps @iteration 96 galerkin = 0.5300882532694351
[ Info: vumps @iteration 97 galerkin = 0.459560575317228
[ Info: vumps @iteration 98 galerkin = 0.5540344299371909
[ Info: vumps @iteration 99 galerkin = 0.39420641359095077
[ Info: vumps @iteration 100 galerkin = 0.5007324793885246
┌ Warning: vumps didn't converge 0.5007324793885246
└ @ MPSKit ~/projects/MPSKit.jl/src/algorithms/groundstate/vumps.jl:69

````

As you can see, VUMPS struggles to converge.
On it's own, that is already quite curious.
Maybe we can do better using another algorithm, such as gradient descent.

````julia
groundstate, cache, delta = find_groundstate(state, H, GradientGrassmann(maxiter=20));
````

````
[ Info: CG: initializing with f = 0.249998045291, ‖∇f‖ = 2.7213e-03
[ Info: CG: iter    1: f = 0.027983869055, ‖∇f‖ = 4.9854e-01, α = 4.53e+06, β = 0.00e+00, nfg = 15
[ Info: CG: iter    2: f = -0.007248790849, ‖∇f‖ = 5.6340e-01, α = 1.70e+03, β = 5.46e+04, nfg = 6
[ Info: CG: iter    3: f = -0.009065888038, ‖∇f‖ = 5.3992e-01, α = 1.70e+03, β = 8.95e-01, nfg = 14
┌ Warning: resorting to η
└ @ OptimKit ~/.julia/packages/OptimKit/xpmbV/src/cg.jl:139
[ Info: CG: iter    4: f = -0.113399422496, ‖∇f‖ = 5.9410e-01, α = 1.64e+00, β = 1.33e-04, nfg = 13
[ Info: CG: iter    5: f = -0.163354320004, ‖∇f‖ = 6.2182e-01, α = 1.56e+00, β = 3.55e-01, nfg = 3
[ Info: CG: iter    6: f = -0.185885945737, ‖∇f‖ = 6.5958e-01, α = 1.53e+00, β = 2.95e-01, nfg = 3
[ Info: CG: iter    7: f = -0.324574949511, ‖∇f‖ = 5.2427e-01, α = 8.68e-01, β = 2.35e-01, nfg = 3
[ Info: CG: iter    8: f = -0.360508886098, ‖∇f‖ = 4.8227e-01, α = 9.15e-01, β = 2.92e-01, nfg = 2
[ Info: CG: iter    9: f = -0.416239990466, ‖∇f‖ = 2.4436e-01, α = 4.88e-01, β = 1.22e-01, nfg = 3
[ Info: CG: iter   10: f = -0.428092734623, ‖∇f‖ = 1.6497e-01, α = 3.33e-01, β = 2.48e-01, nfg = 2
[ Info: CG: iter   11: f = -0.433514580822, ‖∇f‖ = 1.2579e-01, α = 2.74e-01, β = 3.22e-01, nfg = 2
[ Info: CG: iter   12: f = -0.436203941069, ‖∇f‖ = 1.0199e-01, α = 2.03e-01, β = 4.42e-01, nfg = 2
[ Info: CG: iter   13: f = -0.438441798247, ‖∇f‖ = 7.7849e-02, α = 3.00e-01, β = 3.58e-01, nfg = 2
[ Info: CG: iter   14: f = -0.440123669198, ‖∇f‖ = 5.4230e-02, α = 4.41e-01, β = 2.67e-01, nfg = 2
[ Info: CG: iter   15: f = -0.440752043066, ‖∇f‖ = 4.4439e-02, α = 2.43e-01, β = 3.95e-01, nfg = 2
[ Info: CG: iter   16: f = -0.441068862280, ‖∇f‖ = 3.9089e-02, α = 1.15e-01, β = 8.18e-01, nfg = 2
[ Info: CG: iter   17: f = -0.441381839812, ‖∇f‖ = 3.6473e-02, α = 2.32e-01, β = 4.16e-01, nfg = 3
[ Info: CG: iter   18: f = -0.441746553345, ‖∇f‖ = 3.1605e-02, α = 4.37e-01, β = 2.63e-01, nfg = 2
[ Info: CG: iter   19: f = -0.442016272848, ‖∇f‖ = 2.4861e-02, α = 3.32e-01, β = 4.30e-01, nfg = 2
┌ Warning: CG: not converged to requested tol: f = -0.442115096391, ‖∇f‖ = 2.3694e-02
└ @ OptimKit ~/.julia/packages/OptimKit/xpmbV/src/cg.jl:103

````

Convergence is quite slow and even fails after sufficiently many iterations.
To understand why, we can look at the transfer matrix spectrum.

````julia
transferplot(groundstate, groundstate)
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip430">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip430)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip431">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip430)" d="M102.74 1505.26 L2352.76 1505.26 L2352.76 47.2441 L102.74 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip432">
    <rect x="102" y="47" width="2251" height="1459"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="166.42,1505.26 166.42,47.2441 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="520.196,1505.26 520.196,47.2441 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="873.972,1505.26 873.972,47.2441 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1227.75,1505.26 1227.75,47.2441 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1581.52,1505.26 1581.52,47.2441 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="1935.3,1505.26 1935.3,47.2441 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="2289.08,1505.26 2289.08,47.2441 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="102.74,1505.26 2352.76,1505.26 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="166.42,1505.26 166.42,1486.36 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="520.196,1505.26 520.196,1486.36 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="873.972,1505.26 873.972,1486.36 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1227.75,1505.26 1227.75,1486.36 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1581.52,1505.26 1581.52,1486.36 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1935.3,1505.26 1935.3,1486.36 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2289.08,1505.26 2289.08,1486.36 "/>
<path clip-path="url(#clip430)" d="M120.182 1536.18 Q116.571 1536.18 114.742 1539.74 Q112.936 1543.28 112.936 1550.41 Q112.936 1557.52 114.742 1561.09 Q116.571 1564.63 120.182 1564.63 Q123.816 1564.63 125.621 1561.09 Q127.45 1557.52 127.45 1550.41 Q127.45 1543.28 125.621 1539.74 Q123.816 1536.18 120.182 1536.18 M120.182 1532.47 Q125.992 1532.47 129.047 1537.08 Q132.126 1541.66 132.126 1550.41 Q132.126 1559.14 129.047 1563.75 Q125.992 1568.33 120.182 1568.33 Q114.372 1568.33 111.293 1563.75 Q108.237 1559.14 108.237 1550.41 Q108.237 1541.66 111.293 1537.08 Q114.372 1532.47 120.182 1532.47 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M147.311 1533.1 L151.246 1533.1 L139.209 1572.06 L135.274 1572.06 L147.311 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M163.283 1533.1 L167.218 1533.1 L155.181 1572.06 L151.246 1572.06 L163.283 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M173.098 1563.72 L180.737 1563.72 L180.737 1537.36 L172.427 1539.03 L172.427 1534.77 L180.691 1533.1 L185.367 1533.1 L185.367 1563.72 L193.005 1563.72 L193.005 1567.66 L173.098 1567.66 L173.098 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M199.093 1541.73 L223.931 1541.73 L223.931 1545.99 L220.667 1545.99 L220.667 1561.92 Q220.667 1563.59 221.223 1564.33 Q221.801 1565.04 223.075 1565.04 Q223.422 1565.04 223.931 1565 Q224.44 1564.93 224.602 1564.91 L224.602 1567.98 Q223.792 1568.28 222.936 1568.42 Q222.079 1568.56 221.223 1568.56 Q218.445 1568.56 217.38 1567.06 Q216.315 1565.53 216.315 1561.46 L216.315 1545.99 L206.755 1545.99 L206.755 1567.66 L202.403 1567.66 L202.403 1545.99 L199.093 1545.99 L199.093 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M463.726 1563.72 L471.365 1563.72 L471.365 1537.36 L463.055 1539.03 L463.055 1534.77 L471.319 1533.1 L475.995 1533.1 L475.995 1563.72 L483.634 1563.72 L483.634 1567.66 L463.726 1567.66 L463.726 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M500.046 1533.1 L503.981 1533.1 L491.944 1572.06 L488.009 1572.06 L500.046 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M516.018 1533.1 L519.953 1533.1 L507.916 1572.06 L503.981 1572.06 L516.018 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M539.189 1549.03 Q542.545 1549.74 544.42 1552.01 Q546.318 1554.28 546.318 1557.61 Q546.318 1562.73 542.8 1565.53 Q539.281 1568.33 532.8 1568.33 Q530.624 1568.33 528.309 1567.89 Q526.018 1567.47 523.564 1566.62 L523.564 1562.1 Q525.508 1563.24 527.823 1563.82 Q530.138 1564.4 532.661 1564.4 Q537.059 1564.4 539.351 1562.66 Q541.666 1560.92 541.666 1557.61 Q541.666 1554.56 539.513 1552.85 Q537.383 1551.11 533.564 1551.11 L529.536 1551.11 L529.536 1547.27 L533.749 1547.27 Q537.198 1547.27 539.027 1545.9 Q540.856 1544.51 540.856 1541.92 Q540.856 1539.26 538.957 1537.85 Q537.082 1536.41 533.564 1536.41 Q531.643 1536.41 529.444 1536.83 Q527.244 1537.24 524.606 1538.12 L524.606 1533.96 Q527.268 1533.22 529.582 1532.85 Q531.92 1532.47 533.981 1532.47 Q539.305 1532.47 542.406 1534.91 Q545.508 1537.31 545.508 1541.43 Q545.508 1544.3 543.865 1546.29 Q542.221 1548.26 539.189 1549.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M551.828 1541.73 L576.666 1541.73 L576.666 1545.99 L573.402 1545.99 L573.402 1561.92 Q573.402 1563.59 573.957 1564.33 Q574.536 1565.04 575.809 1565.04 Q576.156 1565.04 576.666 1565 Q577.175 1564.93 577.337 1564.91 L577.337 1567.98 Q576.527 1568.28 575.67 1568.42 Q574.814 1568.56 573.957 1568.56 Q571.179 1568.56 570.115 1567.06 Q569.05 1565.53 569.05 1561.46 L569.05 1545.99 L559.49 1545.99 L559.49 1567.66 L555.138 1567.66 L555.138 1545.99 L551.828 1545.99 L551.828 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M821.588 1563.72 L837.907 1563.72 L837.907 1567.66 L815.963 1567.66 L815.963 1563.72 Q818.625 1560.97 823.208 1556.34 Q827.815 1551.69 828.995 1550.35 Q831.241 1547.82 832.12 1546.09 Q833.023 1544.33 833.023 1542.64 Q833.023 1539.88 831.079 1538.15 Q829.157 1536.41 826.056 1536.41 Q823.856 1536.41 821.403 1537.17 Q818.972 1537.94 816.195 1539.49 L816.195 1534.77 Q819.019 1533.63 821.472 1533.05 Q823.926 1532.47 825.963 1532.47 Q831.333 1532.47 834.528 1535.16 Q837.722 1537.85 837.722 1542.34 Q837.722 1544.47 836.912 1546.39 Q836.125 1548.28 834.018 1550.88 Q833.44 1551.55 830.338 1554.77 Q827.236 1557.96 821.588 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M854.69 1533.1 L858.625 1533.1 L846.588 1572.06 L842.653 1572.06 L854.69 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M870.662 1533.1 L874.597 1533.1 L862.56 1572.06 L858.625 1572.06 L870.662 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M893.833 1549.03 Q897.189 1549.74 899.064 1552.01 Q900.963 1554.28 900.963 1557.61 Q900.963 1562.73 897.444 1565.53 Q893.926 1568.33 887.444 1568.33 Q885.268 1568.33 882.953 1567.89 Q880.662 1567.47 878.208 1566.62 L878.208 1562.1 Q880.152 1563.24 882.467 1563.82 Q884.782 1564.4 887.305 1564.4 Q891.703 1564.4 893.995 1562.66 Q896.31 1560.92 896.31 1557.61 Q896.31 1554.56 894.157 1552.85 Q892.027 1551.11 888.208 1551.11 L884.18 1551.11 L884.18 1547.27 L888.393 1547.27 Q891.842 1547.27 893.671 1545.9 Q895.5 1544.51 895.5 1541.92 Q895.5 1539.26 893.601 1537.85 Q891.727 1536.41 888.208 1536.41 Q886.287 1536.41 884.088 1536.83 Q881.889 1537.24 879.25 1538.12 L879.25 1533.96 Q881.912 1533.22 884.227 1532.85 Q886.564 1532.47 888.625 1532.47 Q893.949 1532.47 897.051 1534.91 Q900.152 1537.31 900.152 1541.43 Q900.152 1544.3 898.509 1546.29 Q896.865 1548.26 893.833 1549.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M906.472 1541.73 L931.31 1541.73 L931.31 1545.99 L928.046 1545.99 L928.046 1561.92 Q928.046 1563.59 928.601 1564.33 Q929.18 1565.04 930.453 1565.04 Q930.8 1565.04 931.31 1565 Q931.819 1564.93 931.981 1564.91 L931.981 1567.98 Q931.171 1568.28 930.314 1568.42 Q929.458 1568.56 928.601 1568.56 Q925.824 1568.56 924.759 1567.06 Q923.694 1565.53 923.694 1561.46 L923.694 1545.99 L914.134 1545.99 L914.134 1567.66 L909.782 1567.66 L909.782 1545.99 L906.472 1545.99 L906.472 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1171.28 1563.72 L1178.92 1563.72 L1178.92 1537.36 L1170.61 1539.03 L1170.61 1534.77 L1178.87 1533.1 L1183.55 1533.1 L1183.55 1563.72 L1191.19 1563.72 L1191.19 1567.66 L1171.28 1567.66 L1171.28 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1207.6 1533.1 L1211.53 1533.1 L1199.5 1572.06 L1195.56 1572.06 L1207.6 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1223.57 1533.1 L1227.5 1533.1 L1215.47 1572.06 L1211.53 1572.06 L1223.57 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1233.38 1563.72 L1241.02 1563.72 L1241.02 1537.36 L1232.71 1539.03 L1232.71 1534.77 L1240.98 1533.1 L1245.65 1533.1 L1245.65 1563.72 L1253.29 1563.72 L1253.29 1567.66 L1233.38 1567.66 L1233.38 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1259.38 1541.73 L1284.22 1541.73 L1284.22 1545.99 L1280.95 1545.99 L1280.95 1561.92 Q1280.95 1563.59 1281.51 1564.33 Q1282.09 1565.04 1283.36 1565.04 Q1283.71 1565.04 1284.22 1565 Q1284.73 1564.93 1284.89 1564.91 L1284.89 1567.98 Q1284.08 1568.28 1283.22 1568.42 Q1282.37 1568.56 1281.51 1568.56 Q1278.73 1568.56 1277.67 1567.06 Q1276.6 1565.53 1276.6 1561.46 L1276.6 1545.99 L1267.04 1545.99 L1267.04 1567.66 L1262.69 1567.66 L1262.69 1545.99 L1259.38 1545.99 L1259.38 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1538.54 1537.17 L1526.73 1555.62 L1538.54 1555.62 L1538.54 1537.17 M1537.31 1533.1 L1543.19 1533.1 L1543.19 1555.62 L1548.12 1555.62 L1548.12 1559.51 L1543.19 1559.51 L1543.19 1567.66 L1538.54 1567.66 L1538.54 1559.51 L1522.94 1559.51 L1522.94 1555 L1537.31 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1562.82 1533.1 L1566.76 1533.1 L1554.72 1572.06 L1550.78 1572.06 L1562.82 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1578.79 1533.1 L1582.73 1533.1 L1570.69 1572.06 L1566.76 1572.06 L1578.79 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1601.96 1549.03 Q1605.32 1549.74 1607.2 1552.01 Q1609.09 1554.28 1609.09 1557.61 Q1609.09 1562.73 1605.57 1565.53 Q1602.06 1568.33 1595.57 1568.33 Q1593.4 1568.33 1591.08 1567.89 Q1588.79 1567.47 1586.34 1566.62 L1586.34 1562.1 Q1588.28 1563.24 1590.6 1563.82 Q1592.91 1564.4 1595.44 1564.4 Q1599.83 1564.4 1602.13 1562.66 Q1604.44 1560.92 1604.44 1557.61 Q1604.44 1554.56 1602.29 1552.85 Q1600.16 1551.11 1596.34 1551.11 L1592.31 1551.11 L1592.31 1547.27 L1596.52 1547.27 Q1599.97 1547.27 1601.8 1545.9 Q1603.63 1544.51 1603.63 1541.92 Q1603.63 1539.26 1601.73 1537.85 Q1599.86 1536.41 1596.34 1536.41 Q1594.42 1536.41 1592.22 1536.83 Q1590.02 1537.24 1587.38 1538.12 L1587.38 1533.96 Q1590.04 1533.22 1592.36 1532.85 Q1594.7 1532.47 1596.76 1532.47 Q1602.08 1532.47 1605.18 1534.91 Q1608.28 1537.31 1608.28 1541.43 Q1608.28 1544.3 1606.64 1546.29 Q1605 1548.26 1601.96 1549.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1614.6 1541.73 L1639.44 1541.73 L1639.44 1545.99 L1636.18 1545.99 L1636.18 1561.92 Q1636.18 1563.59 1636.73 1564.33 Q1637.31 1565.04 1638.58 1565.04 Q1638.93 1565.04 1639.44 1565 Q1639.95 1564.93 1640.11 1564.91 L1640.11 1567.98 Q1639.3 1568.28 1638.45 1568.42 Q1637.59 1568.56 1636.73 1568.56 Q1633.95 1568.56 1632.89 1567.06 Q1631.82 1565.53 1631.82 1561.46 L1631.82 1545.99 L1622.26 1545.99 L1622.26 1567.66 L1617.91 1567.66 L1617.91 1545.99 L1614.6 1545.99 L1614.6 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1878.84 1533.1 L1897.2 1533.1 L1897.2 1537.04 L1883.12 1537.04 L1883.12 1545.51 Q1884.14 1545.16 1885.16 1545 Q1886.18 1544.81 1887.2 1544.81 Q1892.99 1544.81 1896.37 1547.98 Q1899.74 1551.16 1899.74 1556.57 Q1899.74 1562.15 1896.27 1565.25 Q1892.8 1568.33 1886.48 1568.33 Q1884.31 1568.33 1882.04 1567.96 Q1879.79 1567.59 1877.38 1566.85 L1877.38 1562.15 Q1879.47 1563.28 1881.69 1563.84 Q1883.91 1564.4 1886.39 1564.4 Q1890.39 1564.4 1892.73 1562.29 Q1895.07 1560.18 1895.07 1556.57 Q1895.07 1552.96 1892.73 1550.85 Q1890.39 1548.75 1886.39 1548.75 Q1884.51 1548.75 1882.64 1549.16 Q1880.79 1549.58 1878.84 1550.46 L1878.84 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1915.93 1533.1 L1919.86 1533.1 L1907.82 1572.06 L1903.89 1572.06 L1915.93 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1931.9 1533.1 L1935.83 1533.1 L1923.8 1572.06 L1919.86 1572.06 L1931.9 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1955.07 1549.03 Q1958.43 1549.74 1960.3 1552.01 Q1962.2 1554.28 1962.2 1557.61 Q1962.2 1562.73 1958.68 1565.53 Q1955.16 1568.33 1948.68 1568.33 Q1946.5 1568.33 1944.19 1567.89 Q1941.9 1567.47 1939.44 1566.62 L1939.44 1562.1 Q1941.39 1563.24 1943.7 1563.82 Q1946.02 1564.4 1948.54 1564.4 Q1952.94 1564.4 1955.23 1562.66 Q1957.55 1560.92 1957.55 1557.61 Q1957.55 1554.56 1955.39 1552.85 Q1953.26 1551.11 1949.44 1551.11 L1945.42 1551.11 L1945.42 1547.27 L1949.63 1547.27 Q1953.08 1547.27 1954.91 1545.9 Q1956.74 1544.51 1956.74 1541.92 Q1956.74 1539.26 1954.84 1537.85 Q1952.96 1536.41 1949.44 1536.41 Q1947.52 1536.41 1945.32 1536.83 Q1943.12 1537.24 1940.49 1538.12 L1940.49 1533.96 Q1943.15 1533.22 1945.46 1532.85 Q1947.8 1532.47 1949.86 1532.47 Q1955.18 1532.47 1958.29 1534.91 Q1961.39 1537.31 1961.39 1541.43 Q1961.39 1544.3 1959.74 1546.29 Q1958.1 1548.26 1955.07 1549.03 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1967.71 1541.73 L1992.55 1541.73 L1992.55 1545.99 L1989.28 1545.99 L1989.28 1561.92 Q1989.28 1563.59 1989.84 1564.33 Q1990.42 1565.04 1991.69 1565.04 Q1992.04 1565.04 1992.55 1565 Q1993.05 1564.93 1993.22 1564.91 L1993.22 1567.98 Q1992.41 1568.28 1991.55 1568.42 Q1990.69 1568.56 1989.84 1568.56 Q1987.06 1568.56 1985.99 1567.06 Q1984.93 1565.53 1984.93 1561.46 L1984.93 1545.99 L1975.37 1545.99 L1975.37 1567.66 L1971.02 1567.66 L1971.02 1545.99 L1967.71 1545.99 L1967.71 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2236.69 1563.72 L2253.01 1563.72 L2253.01 1567.66 L2231.07 1567.66 L2231.07 1563.72 Q2233.73 1560.97 2238.31 1556.34 Q2242.92 1551.69 2244.1 1550.35 Q2246.34 1547.82 2247.22 1546.09 Q2248.13 1544.33 2248.13 1542.64 Q2248.13 1539.88 2246.18 1538.15 Q2244.26 1536.41 2241.16 1536.41 Q2238.96 1536.41 2236.51 1537.17 Q2234.08 1537.94 2231.3 1539.49 L2231.3 1534.77 Q2234.12 1533.63 2236.58 1533.05 Q2239.03 1532.47 2241.07 1532.47 Q2246.44 1532.47 2249.63 1535.16 Q2252.83 1537.85 2252.83 1542.34 Q2252.83 1544.47 2252.02 1546.39 Q2251.23 1548.28 2249.12 1550.88 Q2248.54 1551.55 2245.44 1554.77 Q2242.34 1557.96 2236.69 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2269.79 1533.1 L2273.73 1533.1 L2261.69 1572.06 L2257.76 1572.06 L2269.79 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2285.77 1533.1 L2289.7 1533.1 L2277.66 1572.06 L2273.73 1572.06 L2285.77 1533.1 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2295.58 1563.72 L2303.22 1563.72 L2303.22 1537.36 L2294.91 1539.03 L2294.91 1534.77 L2303.17 1533.1 L2307.85 1533.1 L2307.85 1563.72 L2315.49 1563.72 L2315.49 1567.66 L2295.58 1567.66 L2295.58 1563.72 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2321.58 1541.73 L2346.41 1541.73 L2346.41 1545.99 L2343.15 1545.99 L2343.15 1561.92 Q2343.15 1563.59 2343.71 1564.33 Q2344.28 1565.04 2345.56 1565.04 Q2345.9 1565.04 2346.41 1565 Q2346.92 1564.93 2347.09 1564.91 L2347.09 1567.98 Q2346.27 1568.28 2345.42 1568.42 Q2344.56 1568.56 2343.71 1568.56 Q2340.93 1568.56 2339.86 1567.06 Q2338.8 1565.53 2338.8 1561.46 L2338.8 1545.99 L2329.24 1545.99 L2329.24 1567.66 L2324.89 1567.66 L2324.89 1545.99 L2321.58 1545.99 L2321.58 1541.73 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M1237.87 1627.53 L1217.59 1627.53 Q1218.07 1637.04 1220.27 1641.08 Q1223.01 1646.05 1227.75 1646.05 Q1232.52 1646.05 1235.16 1641.05 Q1237.49 1636.66 1237.87 1627.53 M1237.77 1622.11 Q1236.88 1613.08 1235.16 1609.89 Q1232.43 1604.86 1227.75 1604.86 Q1222.88 1604.86 1220.3 1609.83 Q1218.26 1613.84 1217.66 1622.11 L1237.77 1622.11 M1227.75 1600.09 Q1235.39 1600.09 1239.75 1606.84 Q1244.11 1613.55 1244.11 1625.46 Q1244.11 1637.33 1239.75 1644.08 Q1235.39 1650.86 1227.75 1650.86 Q1220.08 1650.86 1215.75 1644.08 Q1211.39 1637.33 1211.39 1625.46 Q1211.39 1613.55 1215.75 1606.84 Q1220.08 1600.09 1227.75 1600.09 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="102.74,1261.07 2352.76,1261.07 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="102.74,957.615 2352.76,957.615 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="102.74,654.158 2352.76,654.158 "/>
<polyline clip-path="url(#clip432)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="102.74,350.701 2352.76,350.701 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="102.74,1505.26 102.74,47.2441 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="102.74,1261.07 121.638,1261.07 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="102.74,957.615 121.638,957.615 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="102.74,654.158 121.638,654.158 "/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="102.74,350.701 121.638,350.701 "/>
<path clip-path="url(#clip430)" d="M-19.602 1246.87 Q-23.2131 1246.87 -25.0418 1250.44 Q-26.8473 1253.98 -26.8473 1261.11 Q-26.8473 1268.21 -25.0418 1271.78 Q-23.2131 1275.32 -19.602 1275.32 Q-15.9677 1275.32 -14.1622 1271.78 Q-12.3335 1268.21 -12.3335 1261.11 Q-12.3335 1253.98 -14.1622 1250.44 Q-15.9677 1246.87 -19.602 1246.87 M-19.602 1243.17 Q-13.7918 1243.17 -10.7363 1247.77 Q-7.65759 1252.36 -7.65759 1261.11 Q-7.65759 1269.83 -10.7363 1274.44 Q-13.7918 1279.02 -19.602 1279.02 Q-25.4121 1279.02 -28.4908 1274.44 Q-31.5464 1269.83 -31.5464 1261.11 Q-31.5464 1252.36 -28.4908 1247.77 Q-25.4121 1243.17 -19.602 1243.17 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M0.559957 1272.47 L5.44419 1272.47 L5.44419 1278.35 L0.559957 1278.35 L0.559957 1272.47 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M25.6293 1261.94 Q22.296 1261.94 20.3747 1263.72 Q18.4765 1265.51 18.4765 1268.63 Q18.4765 1271.76 20.3747 1273.54 Q22.296 1275.32 25.6293 1275.32 Q28.9626 1275.32 30.8839 1273.54 Q32.8052 1271.73 32.8052 1268.63 Q32.8052 1265.51 30.8839 1263.72 Q28.9857 1261.94 25.6293 1261.94 M20.9534 1259.95 Q17.9441 1259.21 16.2543 1257.15 Q14.5877 1255.09 14.5877 1252.13 Q14.5877 1247.98 17.5275 1245.57 Q20.4904 1243.17 25.6293 1243.17 Q30.7913 1243.17 33.7311 1245.57 Q36.6709 1247.98 36.6709 1252.13 Q36.6709 1255.09 34.9811 1257.15 Q33.3144 1259.21 30.3283 1259.95 Q33.7079 1260.74 35.5829 1263.03 Q37.4811 1265.32 37.4811 1268.63 Q37.4811 1273.65 34.4024 1276.34 Q31.3468 1279.02 25.6293 1279.02 Q19.9117 1279.02 16.833 1276.34 Q13.7775 1273.65 13.7775 1268.63 Q13.7775 1265.32 15.6756 1263.03 Q17.5738 1260.74 20.9534 1259.95 M19.2404 1252.57 Q19.2404 1255.25 20.9071 1256.76 Q22.5969 1258.26 25.6293 1258.26 Q28.6385 1258.26 30.3283 1256.76 Q32.0413 1255.25 32.0413 1252.57 Q32.0413 1249.88 30.3283 1248.38 Q28.6385 1246.87 25.6293 1246.87 Q22.5969 1246.87 20.9071 1248.38 Q19.2404 1249.88 19.2404 1252.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M45.8375 1243.79 L64.1939 1243.79 L64.1939 1247.73 L50.1199 1247.73 L50.1199 1256.2 Q51.1384 1255.85 52.1569 1255.69 Q53.1754 1255.51 54.1939 1255.51 Q59.9809 1255.51 63.3605 1258.68 Q66.7402 1261.85 66.7402 1267.26 Q66.7402 1272.84 63.268 1275.94 Q59.7958 1279.02 53.4763 1279.02 Q51.3004 1279.02 49.0319 1278.65 Q46.7866 1278.28 44.3792 1277.54 L44.3792 1272.84 Q46.4625 1273.98 48.6847 1274.53 Q50.9069 1275.09 53.3837 1275.09 Q57.3884 1275.09 59.7263 1272.98 Q62.0643 1270.88 62.0643 1267.26 Q62.0643 1263.65 59.7263 1261.55 Q57.3884 1259.44 53.3837 1259.44 Q51.5088 1259.44 49.6338 1259.86 Q47.7819 1260.27 45.8375 1261.15 L45.8375 1243.79 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M-20.5973 943.414 Q-24.2084 943.414 -26.0371 946.979 Q-27.8427 950.52 -27.8427 957.65 Q-27.8427 964.756 -26.0371 968.321 Q-24.2084 971.863 -20.5973 971.863 Q-16.9631 971.863 -15.1576 968.321 Q-13.3289 964.756 -13.3289 957.65 Q-13.3289 950.52 -15.1576 946.979 Q-16.9631 943.414 -20.5973 943.414 M-20.5973 939.71 Q-14.7872 939.71 -11.7316 944.317 Q-8.65296 948.9 -8.65296 957.65 Q-8.65296 966.377 -11.7316 970.983 Q-14.7872 975.567 -20.5973 975.567 Q-26.4075 975.567 -29.4862 970.983 Q-32.5417 966.377 -32.5417 957.65 Q-32.5417 948.9 -29.4862 944.317 Q-26.4075 939.71 -20.5973 939.71 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M-0.435408 969.016 L4.44882 969.016 L4.44882 974.895 L-0.435408 974.895 L-0.435408 969.016 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M14.7728 974.178 L14.7728 969.918 Q16.5321 970.752 18.3376 971.192 Q20.1432 971.631 21.8793 971.631 Q26.5089 971.631 28.9394 968.53 Q31.3931 965.405 31.7403 959.062 Q30.3978 961.053 28.3376 962.118 Q26.2774 963.182 23.7774 963.182 Q18.5923 963.182 15.5599 960.057 Q12.5506 956.909 12.5506 951.469 Q12.5506 946.145 15.6988 942.928 Q18.8469 939.71 24.0783 939.71 Q30.0737 939.71 33.2218 944.317 Q36.3931 948.9 36.3931 957.65 Q36.3931 965.821 32.5042 970.705 Q28.6385 975.567 22.0876 975.567 Q20.3284 975.567 18.5228 975.219 Q16.7173 974.872 14.7728 974.178 M24.0783 959.525 Q27.2265 959.525 29.0552 957.372 Q30.907 955.219 30.907 951.469 Q30.907 947.743 29.0552 945.59 Q27.2265 943.414 24.0783 943.414 Q20.9302 943.414 19.0784 945.59 Q17.2497 947.743 17.2497 951.469 Q17.2497 955.219 19.0784 957.372 Q20.9302 959.525 24.0783 959.525 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M54.7958 943.414 Q51.1847 943.414 49.356 946.979 Q47.5504 950.52 47.5504 957.65 Q47.5504 964.756 49.356 968.321 Q51.1847 971.863 54.7958 971.863 Q58.43 971.863 60.2356 968.321 Q62.0643 964.756 62.0643 957.65 Q62.0643 950.52 60.2356 946.979 Q58.43 943.414 54.7958 943.414 M54.7958 939.71 Q60.6059 939.71 63.6615 944.317 Q66.7402 948.9 66.7402 957.65 Q66.7402 966.377 63.6615 970.983 Q60.6059 975.567 54.7958 975.567 Q48.9856 975.567 45.9069 970.983 Q42.8514 966.377 42.8514 957.65 Q42.8514 948.9 45.9069 944.317 Q48.9856 939.71 54.7958 939.71 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M-19.602 639.957 Q-23.2131 639.957 -25.0418 643.522 Q-26.8473 647.063 -26.8473 654.193 Q-26.8473 661.299 -25.0418 664.864 Q-23.2131 668.406 -19.602 668.406 Q-15.9677 668.406 -14.1622 664.864 Q-12.3335 661.299 -12.3335 654.193 Q-12.3335 647.063 -14.1622 643.522 Q-15.9677 639.957 -19.602 639.957 M-19.602 636.253 Q-13.7918 636.253 -10.7363 640.86 Q-7.65759 645.443 -7.65759 654.193 Q-7.65759 662.92 -10.7363 667.526 Q-13.7918 672.109 -19.602 672.109 Q-25.4121 672.109 -28.4908 667.526 Q-31.5464 662.92 -31.5464 654.193 Q-31.5464 645.443 -28.4908 640.86 Q-25.4121 636.253 -19.602 636.253 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M0.559957 665.559 L5.44419 665.559 L5.44419 671.438 L0.559957 671.438 L0.559957 665.559 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M15.7682 670.721 L15.7682 666.461 Q17.5275 667.295 19.333 667.734 Q21.1385 668.174 22.8747 668.174 Q27.5043 668.174 29.9348 665.072 Q32.3885 661.947 32.7357 655.605 Q31.3931 657.596 29.333 658.66 Q27.2728 659.725 24.7728 659.725 Q19.5876 659.725 16.5552 656.6 Q13.546 653.452 13.546 648.012 Q13.546 642.688 16.6941 639.471 Q19.8423 636.253 25.0737 636.253 Q31.0691 636.253 34.2172 640.86 Q37.3885 645.443 37.3885 654.193 Q37.3885 662.364 33.4996 667.248 Q29.6339 672.109 23.083 672.109 Q21.3237 672.109 19.5182 671.762 Q17.7126 671.415 15.7682 670.721 M25.0737 656.068 Q28.2218 656.068 30.0505 653.915 Q31.9024 651.762 31.9024 648.012 Q31.9024 644.286 30.0505 642.133 Q28.2218 639.957 25.0737 639.957 Q21.9256 639.957 20.0737 642.133 Q18.245 644.286 18.245 648.012 Q18.245 651.762 20.0737 653.915 Q21.9256 656.068 25.0737 656.068 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M45.8375 636.878 L64.1939 636.878 L64.1939 640.813 L50.1199 640.813 L50.1199 649.286 Q51.1384 648.938 52.1569 648.776 Q53.1754 648.591 54.1939 648.591 Q59.9809 648.591 63.3605 651.762 Q66.7402 654.934 66.7402 660.35 Q66.7402 665.929 63.268 669.031 Q59.7958 672.109 53.4763 672.109 Q51.3004 672.109 49.0319 671.739 Q46.7866 671.369 44.3792 670.628 L44.3792 665.929 Q46.4625 667.063 48.6847 667.619 Q50.9069 668.174 53.3837 668.174 Q57.3884 668.174 59.7263 666.068 Q62.0643 663.961 62.0643 660.35 Q62.0643 656.739 59.7263 654.633 Q57.3884 652.526 53.3837 652.526 Q51.5088 652.526 49.6338 652.943 Q47.7819 653.36 45.8375 654.239 L45.8375 636.878 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M-29.7871 364.046 L-22.1483 364.046 L-22.1483 337.68 L-30.4584 339.347 L-30.4584 335.088 L-22.1946 333.421 L-17.5187 333.421 L-17.5187 364.046 L-9.8798 364.046 L-9.8798 367.981 L-29.7871 367.981 L-29.7871 364.046 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M-0.435408 362.102 L4.44882 362.102 L4.44882 367.981 L-0.435408 367.981 L-0.435408 362.102 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M24.6339 336.5 Q21.0228 336.5 19.1941 340.065 Q17.3886 343.606 17.3886 350.736 Q17.3886 357.842 19.1941 361.407 Q21.0228 364.949 24.6339 364.949 Q28.2681 364.949 30.0737 361.407 Q31.9024 357.842 31.9024 350.736 Q31.9024 343.606 30.0737 340.065 Q28.2681 336.5 24.6339 336.5 M24.6339 332.796 Q30.4441 332.796 33.4996 337.403 Q36.5783 341.986 36.5783 350.736 Q36.5783 359.463 33.4996 364.069 Q30.4441 368.652 24.6339 368.652 Q18.8237 368.652 15.7451 364.069 Q12.6895 359.463 12.6895 350.736 Q12.6895 341.986 15.7451 337.403 Q18.8237 332.796 24.6339 332.796 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M54.7958 336.5 Q51.1847 336.5 49.356 340.065 Q47.5504 343.606 47.5504 350.736 Q47.5504 357.842 49.356 361.407 Q51.1847 364.949 54.7958 364.949 Q58.43 364.949 60.2356 361.407 Q62.0643 357.842 62.0643 350.736 Q62.0643 343.606 60.2356 340.065 Q58.43 336.5 54.7958 336.5 M54.7958 332.796 Q60.6059 332.796 63.6615 337.403 Q66.7402 341.986 66.7402 350.736 Q66.7402 359.463 63.6615 364.069 Q60.6059 368.652 54.7958 368.652 Q48.9856 368.652 45.9069 364.069 Q42.8514 359.463 42.8514 350.736 Q42.8514 341.986 45.9069 337.403 Q48.9856 332.796 54.7958 332.796 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M-112.971 765.812 Q-113.544 766.799 -113.799 767.977 Q-114.085 769.122 -114.085 770.523 Q-114.085 775.488 -110.839 778.162 Q-107.624 780.803 -101.577 780.803 L-82.7977 780.803 L-82.7977 786.692 L-118.446 786.692 L-118.446 780.803 L-112.908 780.803 Q-116.154 778.957 -117.714 775.997 Q-119.305 773.037 -119.305 768.804 Q-119.305 768.199 -119.21 767.467 Q-119.146 766.735 -118.987 765.844 L-112.971 765.812 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><line clip-path="url(#clip432)" x1="166.42" y1="350.701" x2="166.42" y2="334.701" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="166.42" y1="350.701" x2="150.42" y2="350.701" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="166.42" y1="350.701" x2="166.42" y2="366.701" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="166.42" y1="350.701" x2="182.42" y2="350.701" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1227.75" y1="350.753" x2="1227.75" y2="334.753" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1227.75" y1="350.753" x2="1211.75" y2="350.753" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1227.75" y1="350.753" x2="1227.75" y2="366.753" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1227.75" y1="350.753" x2="1243.75" y2="350.753" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="700.474" y1="698.36" x2="700.474" y2="682.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="700.474" y1="698.36" x2="684.474" y2="698.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="700.474" y1="698.36" x2="700.474" y2="714.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="700.474" y1="698.36" x2="716.474" y2="698.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1755.02" y1="698.36" x2="1755.02" y2="682.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1755.02" y1="698.36" x2="1739.02" y2="698.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1755.02" y1="698.36" x2="1755.02" y2="714.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1755.02" y1="698.36" x2="1771.02" y2="698.36" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1761.8" y1="698.372" x2="1761.8" y2="682.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1761.8" y1="698.372" x2="1745.8" y2="698.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1761.8" y1="698.372" x2="1761.8" y2="714.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1761.8" y1="698.372" x2="1777.8" y2="698.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="693.694" y1="698.372" x2="693.694" y2="682.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="693.694" y1="698.372" x2="677.694" y2="698.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="693.694" y1="698.372" x2="693.694" y2="714.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="693.694" y1="698.372" x2="709.694" y2="698.372" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1413.8" y1="1032.39" x2="1413.8" y2="1016.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1413.8" y1="1032.39" x2="1397.8" y2="1032.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1413.8" y1="1032.39" x2="1413.8" y2="1048.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1413.8" y1="1032.39" x2="1429.8" y2="1032.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1041.7" y1="1032.39" x2="1041.7" y2="1016.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1041.7" y1="1032.39" x2="1025.7" y2="1032.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1041.7" y1="1032.39" x2="1041.7" y2="1048.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1041.7" y1="1032.39" x2="1057.7" y2="1032.39" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2103.03" y1="1032.49" x2="2103.03" y2="1016.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2103.03" y1="1032.49" x2="2087.03" y2="1032.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2103.03" y1="1032.49" x2="2103.03" y2="1048.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2103.03" y1="1032.49" x2="2119.03" y2="1032.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="352.469" y1="1032.49" x2="352.469" y2="1016.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="352.469" y1="1032.49" x2="336.469" y2="1032.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="352.469" y1="1032.49" x2="352.469" y2="1048.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="352.469" y1="1032.49" x2="368.469" y2="1032.49" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="881.331" y1="1334.86" x2="881.331" y2="1318.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="881.331" y1="1334.86" x2="865.331" y2="1334.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="881.331" y1="1334.86" x2="881.331" y2="1350.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="881.331" y1="1334.86" x2="897.331" y2="1334.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1574.17" y1="1334.86" x2="1574.17" y2="1318.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1574.17" y1="1334.86" x2="1558.17" y2="1334.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1574.17" y1="1334.86" x2="1574.17" y2="1350.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1574.17" y1="1334.86" x2="1590.17" y2="1334.86" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1942.65" y1="1335.23" x2="1942.65" y2="1319.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1942.65" y1="1335.23" x2="1926.65" y2="1335.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1942.65" y1="1335.23" x2="1942.65" y2="1351.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1942.65" y1="1335.23" x2="1958.65" y2="1335.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="512.846" y1="1335.23" x2="512.846" y2="1319.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="512.846" y1="1335.23" x2="496.846" y2="1335.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="512.846" y1="1335.23" x2="512.846" y2="1351.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="512.846" y1="1335.23" x2="528.846" y2="1335.23" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1340.72" y1="1360.14" x2="1340.72" y2="1344.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1340.72" y1="1360.14" x2="1324.72" y2="1360.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1340.72" y1="1360.14" x2="1340.72" y2="1376.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1340.72" y1="1360.14" x2="1356.72" y2="1360.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1114.78" y1="1360.14" x2="1114.78" y2="1344.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1114.78" y1="1360.14" x2="1098.78" y2="1360.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1114.78" y1="1360.14" x2="1114.78" y2="1376.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="1114.78" y1="1360.14" x2="1130.78" y2="1360.14" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="279.39" y1="1360.16" x2="279.39" y2="1344.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="279.39" y1="1360.16" x2="263.39" y2="1360.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="279.39" y1="1360.16" x2="279.39" y2="1376.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="279.39" y1="1360.16" x2="295.39" y2="1360.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2176.11" y1="1360.16" x2="2176.11" y2="1344.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2176.11" y1="1360.16" x2="2160.11" y2="1360.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2176.11" y1="1360.16" x2="2176.11" y2="1376.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2176.11" y1="1360.16" x2="2192.11" y2="1360.16" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2289.08" y1="1495.64" x2="2289.08" y2="1479.64" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2289.08" y1="1495.64" x2="2273.08" y2="1495.64" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2289.08" y1="1495.64" x2="2289.08" y2="1511.64" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<line clip-path="url(#clip432)" x1="2289.08" y1="1495.64" x2="2305.08" y2="1495.64" style="stroke:#009af9; stroke-width:3.2; stroke-opacity:1"/>
<path clip-path="url(#clip430)" d="M1881.6 199.525 L2277.76 199.525 L2277.76 95.8446 L1881.6 95.8446  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<polyline clip-path="url(#clip430)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1881.6,199.525 2277.76,199.525 2277.76,95.8446 1881.6,95.8446 1881.6,199.525 "/>
<line clip-path="url(#clip430)" x1="1981.6" y1="147.685" x2="1981.6" y2="124.929" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip430)" x1="1981.6" y1="147.685" x2="1958.84" y2="147.685" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip430)" x1="1981.6" y1="147.685" x2="1981.6" y2="170.44" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<line clip-path="url(#clip430)" x1="1981.6" y1="147.685" x2="2004.35" y2="147.685" style="stroke:#009af9; stroke-width:4.55111; stroke-opacity:1"/>
<path clip-path="url(#clip430)" d="M2081.6 130.405 L2110.83 130.405 L2110.83 134.34 L2098.57 134.34 L2098.57 164.965 L2093.87 164.965 L2093.87 134.34 L2081.6 134.34 L2081.6 130.405 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2123.22 143.02 Q2122.5 142.604 2121.64 142.418 Q2120.81 142.21 2119.79 142.21 Q2116.18 142.21 2114.24 144.571 Q2112.32 146.909 2112.32 151.307 L2112.32 164.965 L2108.03 164.965 L2108.03 139.039 L2112.32 139.039 L2112.32 143.067 Q2113.66 140.705 2115.81 139.571 Q2117.96 138.414 2121.04 138.414 Q2121.48 138.414 2122.02 138.483 Q2122.55 138.53 2123.2 138.645 L2123.22 143.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2127.69 139.039 L2131.95 139.039 L2131.95 164.965 L2127.69 164.965 L2127.69 139.039 M2127.69 128.946 L2131.95 128.946 L2131.95 134.34 L2127.69 134.34 L2127.69 128.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2137.8 139.039 L2142.32 139.039 L2150.42 160.798 L2158.52 139.039 L2163.03 139.039 L2153.31 164.965 L2147.52 164.965 L2137.8 139.039 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2168.91 139.039 L2173.17 139.039 L2173.17 164.965 L2168.91 164.965 L2168.91 139.039 M2168.91 128.946 L2173.17 128.946 L2173.17 134.34 L2168.91 134.34 L2168.91 128.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2193.87 151.932 Q2188.7 151.932 2186.71 153.113 Q2184.72 154.293 2184.72 157.141 Q2184.72 159.409 2186.2 160.752 Q2187.71 162.071 2190.28 162.071 Q2193.82 162.071 2195.95 159.571 Q2198.1 157.048 2198.1 152.881 L2198.1 151.932 L2193.87 151.932 M2202.36 150.173 L2202.36 164.965 L2198.1 164.965 L2198.1 161.029 Q2196.64 163.391 2194.47 164.525 Q2192.29 165.636 2189.14 165.636 Q2185.16 165.636 2182.8 163.414 Q2180.46 161.168 2180.46 157.418 Q2180.46 153.043 2183.38 150.821 Q2186.32 148.599 2192.13 148.599 L2198.1 148.599 L2198.1 148.182 Q2198.1 145.243 2196.16 143.645 Q2194.24 142.025 2190.74 142.025 Q2188.52 142.025 2186.41 142.557 Q2184.31 143.09 2182.36 144.155 L2182.36 140.219 Q2184.7 139.317 2186.9 138.877 Q2189.1 138.414 2191.18 138.414 Q2196.81 138.414 2199.58 141.33 Q2202.36 144.247 2202.36 150.173 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2211.14 128.946 L2215.39 128.946 L2215.39 164.965 L2211.14 164.965 L2211.14 128.946 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2234.54 128.993 Q2231.44 134.317 2229.93 139.525 Q2228.43 144.733 2228.43 150.08 Q2228.43 155.428 2229.93 160.682 Q2231.46 165.914 2234.54 171.215 L2230.83 171.215 Q2227.36 165.775 2225.63 160.52 Q2223.91 155.266 2223.91 150.08 Q2223.91 144.918 2225.63 139.687 Q2227.34 134.456 2230.83 128.993 L2234.54 128.993 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip430)" d="M2242.13 128.993 L2245.83 128.993 Q2249.31 134.456 2251.02 139.687 Q2252.76 144.918 2252.76 150.08 Q2252.76 155.266 2251.02 160.52 Q2249.31 165.775 2245.83 171.215 L2242.13 171.215 Q2245.21 165.914 2246.71 160.682 Q2248.24 155.428 2248.24 150.08 Q2248.24 144.733 2246.71 139.525 Q2245.21 134.317 2242.13 128.993 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /></svg>

```

We can clearly see multiple eigenvalues close to the unit circle.
Our state is close to being non-injective, and represents the sum of multiple injective states.
This is numerically very problematic, but also indicates that we used an incorrect ansatz to approximate the groundstate.
We should retry with a larger unit cell.

## Success

Let's initialize a different initial state, this time with a 2-site unit cell:

````julia
A = TensorMap(rand, ComplexF64, ℂ^20 * ℂ^2, ℂ^20);
B = TensorMap(rand, ComplexF64, ℂ^20 * ℂ^2, ℂ^20);
state = InfiniteMPS([A, B]);
````

In MPSKit, we require that the periodicity of the hamiltonian equals that of the state it is applied to.
This is not a big obstacle, you can simply repeat the original hamiltonian.
Alternatively, the hamiltonian can be constructed directly on a two-site unitcell by making use of MPSKitModels.jl's `@mpoham`.

````julia
# H2 = repeat(H, 2); -- copies the one-site version
H2 = heisenberg_XXX(ComplexF64, Trivial, InfiniteChain(2); spin=1//2)
groundstate, cache, delta = find_groundstate(state, H2, VUMPS(maxiter=100, tol_galerkin=1e-12));
````

````
[ Info: vumps @iteration 1 galerkin = 0.02471859426649394
[ Info: vumps @iteration 2 galerkin = 0.5336462487537379
[ Info: vumps @iteration 3 galerkin = 0.0569498471517149
[ Info: vumps @iteration 4 galerkin = 0.011737509034280391
[ Info: vumps @iteration 5 galerkin = 0.005671183022423362
[ Info: vumps @iteration 6 galerkin = 0.004077548522492758
[ Info: vumps @iteration 7 galerkin = 0.00346337288080226
[ Info: vumps @iteration 8 galerkin = 0.0034035609887699382
[ Info: vumps @iteration 9 galerkin = 0.00287009341833206
[ Info: vumps @iteration 10 galerkin = 0.0025564618256067205
[ Info: vumps @iteration 11 galerkin = 0.0021642270141732705
[ Info: vumps @iteration 12 galerkin = 0.0018441235813095455
[ Info: vumps @iteration 13 galerkin = 0.0014633303800817082
[ Info: vumps @iteration 14 galerkin = 0.0011712932289634713
[ Info: vumps @iteration 15 galerkin = 0.0009913458194573896
[ Info: vumps @iteration 16 galerkin = 0.0008217238684913961
[ Info: vumps @iteration 17 galerkin = 0.0007361821761678524
[ Info: vumps @iteration 18 galerkin = 0.0006617948964504855
[ Info: vumps @iteration 19 galerkin = 0.0006489547393933417
[ Info: vumps @iteration 20 galerkin = 0.0006407065150521205
[ Info: vumps @iteration 21 galerkin = 0.0006743676283582835
[ Info: vumps @iteration 22 galerkin = 0.0006961838099902785
[ Info: vumps @iteration 23 galerkin = 0.0007643378799570455
[ Info: vumps @iteration 24 galerkin = 0.0007875205457767738
[ Info: vumps @iteration 25 galerkin = 0.0008815286455277601
[ Info: vumps @iteration 26 galerkin = 0.0008558478898623038
[ Info: vumps @iteration 27 galerkin = 0.0009116355699367757
[ Info: vumps @iteration 28 galerkin = 0.0007623629840894187
[ Info: vumps @iteration 29 galerkin = 0.000672377451120019
[ Info: vumps @iteration 30 galerkin = 0.00048085346690758047
[ Info: vumps @iteration 31 galerkin = 0.00035449545930500026
[ Info: vumps @iteration 32 galerkin = 0.00024413974829683903
[ Info: vumps @iteration 33 galerkin = 0.00017834863026853348
[ Info: vumps @iteration 34 galerkin = 0.00012808618458122543
[ Info: vumps @iteration 35 galerkin = 0.00010326719961492054
[ Info: vumps @iteration 36 galerkin = 7.867589343745876e-5
[ Info: vumps @iteration 37 galerkin = 7.053565151804916e-5
[ Info: vumps @iteration 38 galerkin = 5.948713817537439e-5
[ Info: vumps @iteration 39 galerkin = 5.422654237532789e-5
[ Info: vumps @iteration 40 galerkin = 4.845663869976372e-5
[ Info: vumps @iteration 41 galerkin = 4.475633416122732e-5
[ Info: vumps @iteration 42 galerkin = 4.1190093998679165e-5
[ Info: vumps @iteration 43 galerkin = 3.85239925976723e-5
[ Info: vumps @iteration 44 galerkin = 3.6044698840578785e-5
[ Info: vumps @iteration 45 galerkin = 3.404482970387514e-5
[ Info: vumps @iteration 46 galerkin = 3.2188107894692364e-5
[ Info: vumps @iteration 47 galerkin = 3.062569959549822e-5
[ Info: vumps @iteration 48 galerkin = 2.9165433187232117e-5
[ Info: vumps @iteration 49 galerkin = 2.7900865769739046e-5
[ Info: vumps @iteration 50 galerkin = 2.6711166327490825e-5
[ Info: vumps @iteration 51 galerkin = 2.565761829651515e-5
[ Info: vumps @iteration 52 galerkin = 2.4661686248805343e-5
[ Info: vumps @iteration 53 galerkin = 2.376419540361395e-5
[ Info: vumps @iteration 54 galerkin = 2.291251665465714e-5
[ Info: vumps @iteration 55 galerkin = 2.213302486372592e-5
[ Info: vumps @iteration 56 galerkin = 2.1391830433156613e-5
[ Info: vumps @iteration 57 galerkin = 2.0705485004797336e-5
[ Info: vumps @iteration 58 galerkin = 2.005192472064174e-5
[ Info: vumps @iteration 59 galerkin = 1.9441023808069207e-5
[ Info: vumps @iteration 60 galerkin = 1.885852147774356e-5
[ Info: vumps @iteration 61 galerkin = 1.8310012048485025e-5
[ Info: vumps @iteration 62 galerkin = 1.7786308494324262e-5
[ Info: vumps @iteration 63 galerkin = 1.72903624363058e-5
[ Info: vumps @iteration 64 galerkin = 1.6816250191303885e-5
[ Info: vumps @iteration 65 galerkin = 1.6365296440222392e-5
[ Info: vumps @iteration 66 galerkin = 1.593364545283235e-5
[ Info: vumps @iteration 67 galerkin = 1.552165903559916e-5
[ Info: vumps @iteration 68 galerkin = 1.5126791793981698e-5
[ Info: vumps @iteration 69 galerkin = 1.4748867586218179e-5
[ Info: vumps @iteration 70 galerkin = 1.4386169727011887e-5
[ Info: vumps @iteration 71 galerkin = 1.403824545447022e-5
[ Info: vumps @iteration 72 galerkin = 1.3703901794543526e-5
[ Info: vumps @iteration 73 galerkin = 1.338256532221321e-5
[ Info: vumps @iteration 74 galerkin = 1.3073375132290958e-5
[ Info: vumps @iteration 75 galerkin = 1.2775726965457211e-5
[ Info: vumps @iteration 76 galerkin = 1.2488972607840078e-5
[ Info: vumps @iteration 77 galerkin = 1.2212525817334619e-5
[ Info: vumps @iteration 78 galerkin = 1.1945876828772046e-5
[ Info: vumps @iteration 79 galerkin = 1.168848170019128e-5
[ Info: vumps @iteration 80 galerkin = 1.1439923479389565e-5
[ Info: vumps @iteration 81 galerkin = 1.1199710005861933e-5
[ Info: vumps @iteration 82 galerkin = 1.0967489028039206e-5
[ Info: vumps @iteration 83 galerkin = 1.074282179233689e-5
[ Info: vumps @iteration 84 galerkin = 1.0525402955735938e-5
[ Info: vumps @iteration 85 galerkin = 1.0314844781101482e-5
[ Info: vumps @iteration 86 galerkin = 1.0110877760209823e-5
[ Info: vumps @iteration 87 galerkin = 9.913160582105227e-6
[ Info: vumps @iteration 88 galerkin = 9.721452298717816e-6
[ Info: vumps @iteration 89 galerkin = 9.535452900229216e-6
[ Info: vumps @iteration 90 galerkin = 9.354945274958686e-6
[ Info: vumps @iteration 91 galerkin = 9.179665419379877e-6
[ Info: vumps @iteration 92 galerkin = 9.00941678988538e-6
[ Info: vumps @iteration 93 galerkin = 8.843966616555081e-6
[ Info: vumps @iteration 94 galerkin = 8.683136285553438e-6
[ Info: vumps @iteration 95 galerkin = 8.526720081125945e-6
[ Info: vumps @iteration 96 galerkin = 8.374555369559546e-6
[ Info: vumps @iteration 97 galerkin = 8.226459753719479e-6
[ Info: vumps @iteration 98 galerkin = 8.082284990169496e-6
[ Info: vumps @iteration 99 galerkin = 7.941868662016613e-6
[ Info: vumps @iteration 100 galerkin = 7.805075630903694e-6
┌ Warning: vumps didn't converge 7.805075630903694e-6
└ @ MPSKit ~/projects/MPSKit.jl/src/algorithms/groundstate/vumps.jl:69

````

We get convergence, but it takes an enormous amount of iterations.
The reason behind this becomes more obvious at higher bond dimensions:

````julia
groundstate, cache, delta = find_groundstate(state, H2, IDMRG2(trscheme=truncdim(50), maxiter=20, tol_galerkin=1e-12))
entanglementplot(groundstate)
````

```@raw html
<?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip460">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip460)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip461">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip460)" d="M86.9921 1505.26 L2352.76 1505.26 L2352.76 62.9921 L86.9921 62.9921  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip462">
    <rect x="86" y="62" width="2267" height="1443"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip462)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="151.118,1505.26 151.118,62.9921 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,1505.26 2352.76,1505.26 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="151.118,1505.26 151.118,1524.16 "/>
<path clip-path="url(#clip460)" d="M17.8728 1661.2 L38.5457 1640.52 L41.3283 1643.3 L32.6532 1651.98 L54.3082 1673.63 L50.9855 1676.96 L29.3305 1655.3 L20.6554 1663.98 L17.8728 1661.2 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M56.2233 1640.69 Q55.4213 1640.9 54.6847 1641.37 Q53.9481 1641.82 53.2279 1642.54 Q50.6745 1645.09 50.9691 1648.13 Q51.2638 1651.15 54.3737 1654.26 L64.0309 1663.91 L61.0028 1666.94 L42.6705 1648.61 L45.6986 1645.58 L48.5467 1648.43 Q47.8265 1645.81 48.5467 1643.48 Q49.2505 1641.14 51.4275 1638.97 Q51.7384 1638.66 52.164 1638.33 Q52.5732 1637.99 53.1134 1637.61 L56.2233 1640.69 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M56.567 1634.71 L59.5788 1631.7 L77.9111 1650.03 L74.8993 1653.04 L56.567 1634.71 M49.4305 1627.58 L52.4423 1624.56 L56.256 1628.38 L53.2443 1631.39 L49.4305 1627.58 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M63.7199 1627.56 L66.9117 1624.37 L88.0266 1634.02 L78.3694 1612.91 L81.5612 1609.72 L93.0189 1634.92 L88.9268 1639.02 L63.7199 1627.56 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M85.7187 1605.56 L88.7304 1602.55 L107.063 1620.88 L104.051 1623.89 L85.7187 1605.56 M78.5822 1598.42 L81.5939 1595.41 L85.4077 1599.23 L82.3959 1602.24 L78.5822 1598.42 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M112.481 1597.03 Q108.83 1600.68 108.258 1602.92 Q107.685 1605.17 109.698 1607.18 Q111.302 1608.78 113.299 1608.69 Q115.296 1608.56 117.113 1606.74 Q119.617 1604.23 119.355 1600.96 Q119.093 1597.65 116.147 1594.71 L115.476 1594.04 L112.481 1597.03 M117.244 1589.78 L127.703 1600.24 L124.691 1603.25 L121.909 1600.47 Q122.547 1603.17 121.81 1605.51 Q121.057 1607.84 118.831 1610.06 Q116.016 1612.88 112.775 1612.97 Q109.534 1613.04 106.883 1610.39 Q103.789 1607.29 104.28 1603.66 Q104.788 1600.01 108.896 1595.9 L113.119 1591.68 L112.824 1591.39 Q110.746 1589.31 108.241 1589.55 Q105.737 1589.76 103.265 1592.24 Q101.694 1593.81 100.581 1595.67 Q99.4679 1597.54 98.8459 1599.67 L96.0633 1596.88 Q97.0782 1594.59 98.3221 1592.73 Q99.5497 1590.84 101.023 1589.37 Q105 1585.39 109.027 1585.49 Q113.053 1585.59 117.244 1589.78 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M108.438 1568.57 L111.449 1565.56 L136.918 1591.03 L133.906 1594.04 L108.438 1568.57 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M125.019 1552.05 Q126.59 1558.01 129.209 1562.76 Q131.828 1567.5 135.609 1571.29 Q139.39 1575.07 144.169 1577.72 Q148.949 1580.34 154.874 1581.91 L152.255 1584.53 Q145.953 1583.14 141.01 1580.65 Q136.083 1578.14 132.417 1574.48 Q128.767 1570.83 126.279 1565.92 Q123.791 1561.01 122.4 1554.67 L125.019 1552.05 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M130.387 1546.68 L133.006 1544.06 Q139.324 1545.47 144.235 1547.96 Q149.162 1550.43 152.812 1554.08 Q156.478 1557.75 158.966 1562.69 Q161.47 1567.62 162.862 1573.92 L160.243 1576.54 Q158.671 1570.61 156.036 1565.85 Q153.401 1561.05 149.62 1557.27 Q145.839 1553.49 141.076 1550.89 Q136.329 1548.27 130.387 1546.68 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1136.07 1763.92 L1131.33 1751.73 L1121.56 1769.56 L1114.65 1769.56 L1128.46 1744.35 L1122.67 1729.36 Q1121.11 1725.35 1116.21 1725.35 L1114.65 1725.35 L1114.65 1720.32 L1116.88 1720.38 Q1125.09 1720.6 1127.16 1725.92 L1131.87 1738.11 L1141.64 1720.29 L1148.55 1720.29 L1134.73 1745.49 L1140.53 1760.49 Q1142.09 1764.5 1146.99 1764.5 L1148.55 1764.5 L1148.55 1769.53 L1146.32 1769.46 Q1138.11 1769.24 1136.07 1763.92 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1178.05 1726.37 L1218.86 1726.37 L1218.86 1731.71 L1178.05 1731.71 L1178.05 1726.37 M1178.05 1739.35 L1218.86 1739.35 L1218.86 1744.76 L1178.05 1744.76 L1178.05 1739.35 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1253.52 1708.45 L1278.76 1708.45 L1278.76 1713.86 L1259.41 1713.86 L1259.41 1725.51 Q1260.81 1725.03 1262.21 1724.81 Q1263.61 1724.55 1265.01 1724.55 Q1272.96 1724.55 1277.61 1728.91 Q1282.26 1733.27 1282.26 1740.72 Q1282.26 1748.39 1277.48 1752.66 Q1272.71 1756.89 1264.02 1756.89 Q1261.03 1756.89 1257.91 1756.38 Q1254.82 1755.87 1251.51 1754.85 L1251.51 1748.39 Q1254.38 1749.95 1257.43 1750.71 Q1260.49 1751.48 1263.89 1751.48 Q1269.4 1751.48 1272.61 1748.58 Q1275.83 1745.69 1275.83 1740.72 Q1275.83 1735.76 1272.61 1732.86 Q1269.4 1729.96 1263.89 1729.96 Q1261.31 1729.96 1258.74 1730.54 Q1256.19 1731.11 1253.52 1732.32 L1253.52 1708.45 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1308.68 1712.68 Q1303.71 1712.68 1301.2 1717.58 Q1298.71 1722.45 1298.71 1732.25 Q1298.71 1742.03 1301.2 1746.93 Q1303.71 1751.8 1308.68 1751.8 Q1313.67 1751.8 1316.16 1746.93 Q1318.67 1742.03 1318.67 1732.25 Q1318.67 1722.45 1316.16 1717.58 Q1313.67 1712.68 1308.68 1712.68 M1308.68 1707.59 Q1316.66 1707.59 1320.87 1713.92 Q1325.1 1720.22 1325.1 1732.25 Q1325.1 1744.25 1320.87 1750.59 Q1316.66 1756.89 1308.68 1756.89 Q1300.69 1756.89 1296.45 1750.59 Q1292.25 1744.25 1292.25 1732.25 Q1292.25 1720.22 1296.45 1713.92 Q1300.69 1707.59 1308.68 1707.59 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><polyline clip-path="url(#clip462)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="86.9921,1502.22 2352.76,1502.22 "/>
<polyline clip-path="url(#clip462)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="86.9921,1156.2 2352.76,1156.2 "/>
<polyline clip-path="url(#clip462)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="86.9921,810.179 2352.76,810.179 "/>
<polyline clip-path="url(#clip462)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="86.9921,464.156 2352.76,464.156 "/>
<polyline clip-path="url(#clip462)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:2; stroke-opacity:0.1; fill:none" points="86.9921,118.134 2352.76,118.134 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,1505.26 86.9921,62.9921 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,1502.22 105.89,1502.22 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,1156.2 105.89,1156.2 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,810.179 105.89,810.179 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,464.156 105.89,464.156 "/>
<polyline clip-path="url(#clip460)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="86.9921,118.134 105.89,118.134 "/>
<path clip-path="url(#clip460)" d="M-50.8404 1522.02 L-43.2015 1522.02 L-43.2015 1495.65 L-51.5117 1497.32 L-51.5117 1493.06 L-43.2478 1491.39 L-38.5719 1491.39 L-38.5719 1522.02 L-30.9331 1522.02 L-30.9331 1525.95 L-50.8404 1525.95 L-50.8404 1522.02 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-11.4887 1494.47 Q-15.0998 1494.47 -16.9285 1498.04 Q-18.7341 1501.58 -18.7341 1508.71 Q-18.7341 1515.81 -16.9285 1519.38 Q-15.0998 1522.92 -11.4887 1522.92 Q-7.85449 1522.92 -6.04895 1519.38 Q-4.22025 1515.81 -4.22025 1508.71 Q-4.22025 1501.58 -6.04895 1498.04 Q-7.85449 1494.47 -11.4887 1494.47 M-11.4887 1490.77 Q-5.67858 1490.77 -2.62304 1495.37 Q0.455649 1499.96 0.455649 1508.71 Q0.455649 1517.43 -2.62304 1522.04 Q-5.67858 1526.62 -11.4887 1526.62 Q-17.2989 1526.62 -20.3776 1522.04 Q-23.4331 1517.43 -23.4331 1508.71 Q-23.4331 1499.96 -20.3776 1495.37 Q-17.2989 1490.77 -11.4887 1490.77 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M0.455649 1484.87 L24.5672 1484.87 L24.5672 1488.07 L0.455649 1488.07 L0.455649 1484.87 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M43.2057 1473.77 L33.6137 1488.76 L43.2057 1488.76 L43.2057 1473.77 M42.2089 1470.46 L46.9861 1470.46 L46.9861 1488.76 L50.9921 1488.76 L50.9921 1491.92 L46.9861 1491.92 L46.9861 1498.54 L43.2057 1498.54 L43.2057 1491.92 L30.5293 1491.92 L30.5293 1488.25 L42.2089 1470.46 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-49.9188 1175.99 L-42.2799 1175.99 L-42.2799 1149.63 L-50.5901 1151.29 L-50.5901 1147.04 L-42.3262 1145.37 L-37.6503 1145.37 L-37.6503 1175.99 L-30.0115 1175.99 L-30.0115 1179.93 L-49.9188 1179.93 L-49.9188 1175.99 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-10.5672 1148.45 Q-14.1782 1148.45 -16.0069 1152.01 Q-17.8125 1155.55 -17.8125 1162.68 Q-17.8125 1169.79 -16.0069 1173.36 Q-14.1782 1176.9 -10.5672 1176.9 Q-6.93291 1176.9 -5.12736 1173.36 Q-3.29867 1169.79 -3.29867 1162.68 Q-3.29867 1155.55 -5.12736 1152.01 Q-6.93291 1148.45 -10.5672 1148.45 M-10.5672 1144.74 Q-4.757 1144.74 -1.70146 1149.35 Q1.37723 1153.93 1.37723 1162.68 Q1.37723 1171.41 -1.70146 1176.02 Q-4.757 1180.6 -10.5672 1180.6 Q-16.3773 1180.6 -19.456 1176.02 Q-22.5115 1171.41 -22.5115 1162.68 Q-22.5115 1153.93 -19.456 1149.35 Q-16.3773 1144.74 -10.5672 1144.74 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1.37723 1138.85 L25.4888 1138.85 L25.4888 1142.04 L1.37723 1142.04 L1.37723 1138.85 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M45.1993 1137.38 Q47.9265 1137.96 49.4499 1139.8 Q50.9921 1141.65 50.9921 1144.36 Q50.9921 1148.51 48.1333 1150.79 Q45.2746 1153.06 40.0084 1153.06 Q38.2405 1153.06 36.3597 1152.71 Q34.4977 1152.37 32.5041 1151.67 L32.5041 1148 Q34.0839 1148.93 35.9647 1149.4 Q37.8455 1149.87 39.8955 1149.87 Q43.469 1149.87 45.331 1148.46 Q47.2118 1147.05 47.2118 1144.36 Q47.2118 1141.87 45.4626 1140.48 Q43.7323 1139.07 40.629 1139.07 L37.3565 1139.07 L37.3565 1135.95 L40.7795 1135.95 Q43.5819 1135.95 45.0677 1134.84 Q46.5535 1133.71 46.5535 1131.6 Q46.5535 1129.44 45.0113 1128.29 Q43.4878 1127.13 40.629 1127.13 Q39.068 1127.13 37.2813 1127.47 Q35.4945 1127.81 33.3504 1128.52 L33.3504 1125.13 Q35.5133 1124.53 37.3941 1124.23 Q39.2937 1123.93 40.9676 1123.93 Q45.2934 1123.93 47.8136 1125.91 Q50.3339 1127.86 50.3339 1131.21 Q50.3339 1133.54 48.9985 1135.16 Q47.6632 1136.76 45.1993 1137.38 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-49.1477 829.971 L-41.5088 829.971 L-41.5088 803.606 L-49.819 805.272 L-49.819 801.013 L-41.5551 799.347 L-36.8792 799.347 L-36.8792 829.971 L-29.2404 829.971 L-29.2404 833.907 L-49.1477 833.907 L-49.1477 829.971 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-9.79603 802.425 Q-13.4071 802.425 -15.2358 805.99 Q-17.0414 809.532 -17.0414 816.661 Q-17.0414 823.768 -15.2358 827.333 Q-13.4071 830.874 -9.79603 830.874 Q-6.16179 830.874 -4.35625 827.333 Q-2.52755 823.768 -2.52755 816.661 Q-2.52755 809.532 -4.35625 805.99 Q-6.16179 802.425 -9.79603 802.425 M-9.79603 798.722 Q-3.98588 798.722 -0.930339 803.328 Q2.14835 807.911 2.14835 816.661 Q2.14835 825.388 -0.930339 829.995 Q-3.98588 834.578 -9.79603 834.578 Q-15.6062 834.578 -18.6849 829.995 Q-21.7404 825.388 -21.7404 816.661 Q-21.7404 807.911 -18.6849 803.328 Q-15.6062 798.722 -9.79603 798.722 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M2.14835 792.823 L26.2599 792.823 L26.2599 796.02 L2.14835 796.02 L2.14835 792.823 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M37.7326 803.299 L50.9921 803.299 L50.9921 806.496 L33.1624 806.496 L33.1624 803.299 Q35.3253 801.061 39.0492 797.299 Q42.7919 793.519 43.7511 792.428 Q45.5755 790.378 46.2902 788.967 Q47.0237 787.538 47.0237 786.165 Q47.0237 783.927 45.4438 782.516 Q43.8828 781.106 41.3625 781.106 Q39.5758 781.106 37.5822 781.726 Q35.6074 782.347 33.3504 783.607 L33.3504 779.77 Q35.645 778.849 37.6386 778.379 Q39.6322 777.908 41.2873 777.908 Q45.6507 777.908 48.2462 780.09 Q50.8417 782.272 50.8417 785.92 Q50.8417 787.651 50.1834 789.212 Q49.5439 790.754 47.8324 792.861 Q47.3622 793.406 44.842 796.02 Q42.3217 798.616 37.7326 803.299 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-49.4486 483.949 L-41.8097 483.949 L-41.8097 457.583 L-50.1199 459.25 L-50.1199 454.991 L-41.856 453.324 L-37.1801 453.324 L-37.1801 483.949 L-29.5413 483.949 L-29.5413 487.884 L-49.4486 487.884 L-49.4486 483.949 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-10.097 456.403 Q-13.708 456.403 -15.5367 459.967 Q-17.3423 463.509 -17.3423 470.639 Q-17.3423 477.745 -15.5367 481.31 Q-13.708 484.852 -10.097 484.852 Q-6.46272 484.852 -4.65717 481.31 Q-2.82848 477.745 -2.82848 470.639 Q-2.82848 463.509 -4.65717 459.967 Q-6.46272 456.403 -10.097 456.403 M-10.097 452.699 Q-4.2868 452.699 -1.23126 457.305 Q1.84742 461.889 1.84742 470.639 Q1.84742 479.366 -1.23126 483.972 Q-4.2868 488.555 -10.097 488.555 Q-15.9071 488.555 -18.9858 483.972 Q-22.0413 479.366 -22.0413 470.639 Q-22.0413 461.889 -18.9858 457.305 Q-15.9071 452.699 -10.097 452.699 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1.84742 446.8 L25.959 446.8 L25.959 449.998 L1.84742 449.998 L1.84742 446.8 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M34.8174 457.276 L41.024 457.276 L41.024 435.854 L34.272 437.208 L34.272 433.748 L40.9864 432.394 L44.7856 432.394 L44.7856 457.276 L50.9921 457.276 L50.9921 460.474 L34.8174 460.474 L34.8174 457.276 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M-19.7135 137.926 L-12.0747 137.926 L-12.0747 111.561 L-20.3848 113.227 L-20.3848 108.968 L-12.121 107.301 L-7.44506 107.301 L-7.44506 137.926 L0.193787 137.926 L0.193787 141.861 L-19.7135 141.861 L-19.7135 137.926 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M19.6381 110.38 Q16.027 110.38 14.1983 113.945 Q12.3928 117.487 12.3928 124.616 Q12.3928 131.723 14.1983 135.287 Q16.027 138.829 19.6381 138.829 Q23.2724 138.829 25.0779 135.287 Q26.9066 131.723 26.9066 124.616 Q26.9066 117.487 25.0779 113.945 Q23.2724 110.38 19.6381 110.38 M19.6381 106.676 Q25.4483 106.676 28.5038 111.283 Q31.5825 115.866 31.5825 124.616 Q31.5825 133.343 28.5038 137.949 Q25.4483 142.533 19.6381 142.533 Q13.828 142.533 10.7493 137.949 Q7.69375 133.343 7.69375 124.616 Q7.69375 115.866 10.7493 111.283 Q13.828 106.676 19.6381 106.676 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M41.2873 88.8725 Q38.3533 88.8725 36.8675 91.7689 Q35.4005 94.6464 35.4005 100.439 Q35.4005 106.213 36.8675 109.11 Q38.3533 111.987 41.2873 111.987 Q44.2401 111.987 45.7071 109.11 Q47.193 106.213 47.193 100.439 Q47.193 94.6464 45.7071 91.7689 Q44.2401 88.8725 41.2873 88.8725 M41.2873 85.8632 Q46.0081 85.8632 48.4907 89.606 Q50.9921 93.3299 50.9921 100.439 Q50.9921 107.53 48.4907 111.273 Q46.0081 114.996 41.2873 114.996 Q36.5666 114.996 34.0651 111.273 Q31.5825 107.53 31.5825 100.439 Q31.5825 93.3299 34.0651 89.606 Q36.5666 85.8632 41.2873 85.8632 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M720.944 12.096 L759.185 12.096 L759.185 18.9825 L729.127 18.9825 L729.127 36.8875 L757.929 36.8875 L757.929 43.7741 L729.127 43.7741 L729.127 65.6895 L759.914 65.6895 L759.914 72.576 L720.944 72.576 L720.944 12.096 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M810.753 45.1919 L810.753 72.576 L803.299 72.576 L803.299 45.4349 Q803.299 38.994 800.788 35.7938 Q798.276 32.5936 793.253 32.5936 Q787.217 32.5936 783.733 36.4419 Q780.25 40.2903 780.25 46.9338 L780.25 72.576 L772.755 72.576 L772.755 27.2059 L780.25 27.2059 L780.25 34.2544 Q782.923 30.163 786.529 28.1376 Q790.174 26.1121 794.914 26.1121 Q802.732 26.1121 806.743 30.9732 Q810.753 35.7938 810.753 45.1919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M832.992 14.324 L832.992 27.2059 L848.345 27.2059 L848.345 32.9987 L832.992 32.9987 L832.992 57.6282 Q832.992 63.1779 834.491 64.7578 Q836.031 66.3376 840.689 66.3376 L848.345 66.3376 L848.345 72.576 L840.689 72.576 Q832.061 72.576 828.779 69.3758 Q825.498 66.1351 825.498 57.6282 L825.498 32.9987 L820.03 32.9987 L820.03 27.2059 L825.498 27.2059 L825.498 14.324 L832.992 14.324 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M878.768 49.7694 Q869.734 49.7694 866.25 51.8354 Q862.767 53.9013 862.767 58.8839 Q862.767 62.8538 865.359 65.2034 Q867.992 67.5124 872.489 67.5124 Q878.687 67.5124 882.413 63.1374 Q886.181 58.7219 886.181 51.4303 L886.181 49.7694 L878.768 49.7694 M893.634 46.6907 L893.634 72.576 L886.181 72.576 L886.181 65.6895 Q883.629 69.8214 879.821 71.8063 Q876.013 73.7508 870.504 73.7508 Q863.536 73.7508 859.404 69.8619 Q855.313 65.9325 855.313 59.3701 Q855.313 51.7138 860.417 47.825 Q865.562 43.9361 875.729 43.9361 L886.181 43.9361 L886.181 43.2069 Q886.181 38.0623 882.778 35.2672 Q879.416 32.4315 873.299 32.4315 Q869.41 32.4315 865.724 33.3632 Q862.037 34.295 858.635 36.1584 L858.635 29.2718 Q862.726 27.692 866.574 26.9223 Q870.423 26.1121 874.069 26.1121 Q883.912 26.1121 888.773 31.2163 Q893.634 36.3204 893.634 46.6907 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M946.701 45.1919 L946.701 72.576 L939.248 72.576 L939.248 45.4349 Q939.248 38.994 936.736 35.7938 Q934.225 32.5936 929.201 32.5936 Q923.166 32.5936 919.682 36.4419 Q916.198 40.2903 916.198 46.9338 L916.198 72.576 L908.704 72.576 L908.704 27.2059 L916.198 27.2059 L916.198 34.2544 Q918.872 30.163 922.477 28.1376 Q926.123 26.1121 930.862 26.1121 Q938.68 26.1121 942.691 30.9732 Q946.701 35.7938 946.701 45.1919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M991.423 49.3643 Q991.423 41.2625 988.061 36.8065 Q984.739 32.3505 978.703 32.3505 Q972.708 32.3505 969.346 36.8065 Q966.024 41.2625 966.024 49.3643 Q966.024 57.4256 969.346 61.8816 Q972.708 66.3376 978.703 66.3376 Q984.739 66.3376 988.061 61.8816 Q991.423 57.4256 991.423 49.3643 M998.877 66.9452 Q998.877 78.5308 993.732 84.1616 Q988.588 89.8329 977.974 89.8329 Q974.045 89.8329 970.561 89.2252 Q967.077 88.6581 963.796 87.4428 L963.796 80.1917 Q967.077 81.9741 970.278 82.8248 Q973.478 83.6755 976.8 83.6755 Q984.132 83.6755 987.777 79.8271 Q991.423 76.0193 991.423 68.282 L991.423 64.5957 Q989.114 68.6061 985.509 70.5911 Q981.904 72.576 976.881 72.576 Q968.536 72.576 963.432 66.2161 Q958.327 59.8562 958.327 49.3643 Q958.327 38.832 963.432 32.472 Q968.536 26.1121 976.881 26.1121 Q981.904 26.1121 985.509 28.0971 Q989.114 30.082 991.423 34.0924 L991.423 27.2059 L998.877 27.2059 L998.877 66.9452 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1014.23 9.54393 L1021.68 9.54393 L1021.68 72.576 L1014.23 72.576 L1014.23 9.54393 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1076.09 48.0275 L1076.09 51.6733 L1041.82 51.6733 Q1042.3 59.3701 1046.43 63.421 Q1050.61 67.4314 1058.02 67.4314 Q1062.31 67.4314 1066.32 66.3781 Q1070.38 65.3249 1074.35 63.2184 L1074.35 70.267 Q1070.33 71.9684 1066.12 72.8596 Q1061.91 73.7508 1057.57 73.7508 Q1046.72 73.7508 1040.36 67.4314 Q1034.04 61.1119 1034.04 50.3365 Q1034.04 39.1965 1040.03 32.6746 Q1046.07 26.1121 1056.28 26.1121 Q1065.43 26.1121 1070.74 32.0264 Q1076.09 37.9003 1076.09 48.0275 M1068.63 45.84 Q1068.55 39.7232 1065.19 36.0774 Q1061.87 32.4315 1056.36 32.4315 Q1050.12 32.4315 1046.35 35.9558 Q1042.63 39.4801 1042.06 45.8805 L1068.63 45.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1123.64 35.9153 Q1126.44 30.8922 1130.33 28.5022 Q1134.22 26.1121 1139.48 26.1121 Q1146.57 26.1121 1150.42 31.0947 Q1154.27 36.0368 1154.27 45.1919 L1154.27 72.576 L1146.78 72.576 L1146.78 45.4349 Q1146.78 38.913 1144.47 35.7533 Q1142.16 32.5936 1137.42 32.5936 Q1131.63 32.5936 1128.26 36.4419 Q1124.9 40.2903 1124.9 46.9338 L1124.9 72.576 L1117.41 72.576 L1117.41 45.4349 Q1117.41 38.8725 1115.1 35.7533 Q1112.79 32.5936 1107.97 32.5936 Q1102.26 32.5936 1098.89 36.4824 Q1095.53 40.3308 1095.53 46.9338 L1095.53 72.576 L1088.04 72.576 L1088.04 27.2059 L1095.53 27.2059 L1095.53 34.2544 Q1098.08 30.082 1101.65 28.0971 Q1105.21 26.1121 1110.11 26.1121 Q1115.06 26.1121 1118.5 28.6237 Q1121.98 31.1352 1123.64 35.9153 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1207.94 48.0275 L1207.94 51.6733 L1173.67 51.6733 Q1174.16 59.3701 1178.29 63.421 Q1182.46 67.4314 1189.88 67.4314 Q1194.17 67.4314 1198.18 66.3781 Q1202.23 65.3249 1206.2 63.2184 L1206.2 70.267 Q1202.19 71.9684 1197.98 72.8596 Q1193.77 73.7508 1189.43 73.7508 Q1178.58 73.7508 1172.22 67.4314 Q1165.9 61.1119 1165.9 50.3365 Q1165.9 39.1965 1171.89 32.6746 Q1177.93 26.1121 1188.14 26.1121 Q1197.29 26.1121 1202.6 32.0264 Q1207.94 37.9003 1207.94 48.0275 M1200.49 45.84 Q1200.41 39.7232 1197.05 36.0774 Q1193.73 32.4315 1188.22 32.4315 Q1181.98 32.4315 1178.21 35.9558 Q1174.48 39.4801 1173.92 45.8805 L1200.49 45.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1257.89 45.1919 L1257.89 72.576 L1250.44 72.576 L1250.44 45.4349 Q1250.44 38.994 1247.93 35.7938 Q1245.41 32.5936 1240.39 32.5936 Q1234.36 32.5936 1230.87 36.4419 Q1227.39 40.2903 1227.39 46.9338 L1227.39 72.576 L1219.89 72.576 L1219.89 27.2059 L1227.39 27.2059 L1227.39 34.2544 Q1230.06 30.163 1233.67 28.1376 Q1237.31 26.1121 1242.05 26.1121 Q1249.87 26.1121 1253.88 30.9732 Q1257.89 35.7938 1257.89 45.1919 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1280.13 14.324 L1280.13 27.2059 L1295.48 27.2059 L1295.48 32.9987 L1280.13 32.9987 L1280.13 57.6282 Q1280.13 63.1779 1281.63 64.7578 Q1283.17 66.3376 1287.83 66.3376 L1295.48 66.3376 L1295.48 72.576 L1287.83 72.576 Q1279.2 72.576 1275.92 69.3758 Q1272.64 66.1351 1272.64 57.6282 L1272.64 32.9987 L1267.17 32.9987 L1267.17 27.2059 L1272.64 27.2059 L1272.64 14.324 L1280.13 14.324 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1368.24 14.0809 L1368.24 22.0612 Q1363.58 19.8332 1359.45 18.7395 Q1355.32 17.6457 1351.47 17.6457 Q1344.78 17.6457 1341.14 20.2383 Q1337.53 22.8309 1337.53 27.611 Q1337.53 31.6214 1339.92 33.6873 Q1342.35 35.7128 1349.08 36.9686 L1354.02 37.9813 Q1363.17 39.7232 1367.51 44.1387 Q1371.88 48.5136 1371.88 55.8863 Q1371.88 64.6767 1365.97 69.2137 Q1360.1 73.7508 1348.71 73.7508 Q1344.42 73.7508 1339.56 72.7785 Q1334.74 71.8063 1329.55 69.9024 L1329.55 61.4765 Q1334.53 64.2716 1339.31 65.6895 Q1344.09 67.1073 1348.71 67.1073 Q1355.72 67.1073 1359.53 64.3527 Q1363.34 61.598 1363.34 56.4939 Q1363.34 52.0379 1360.58 49.5264 Q1357.87 47.0148 1351.63 45.759 L1346.65 44.7868 Q1337.49 42.9639 1333.4 39.075 Q1329.31 35.1862 1329.31 28.2591 Q1329.31 20.2383 1334.94 15.6203 Q1340.61 11.0023 1350.54 11.0023 Q1354.79 11.0023 1359.2 11.7719 Q1363.62 12.5416 1368.24 14.0809 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1391.53 65.7705 L1391.53 89.8329 L1384.04 89.8329 L1384.04 27.2059 L1391.53 27.2059 L1391.53 34.0924 Q1393.88 30.0415 1397.45 28.0971 Q1401.05 26.1121 1406.03 26.1121 Q1414.3 26.1121 1419.44 32.6746 Q1424.63 39.2371 1424.63 49.9314 Q1424.63 60.6258 1419.44 67.1883 Q1414.3 73.7508 1406.03 73.7508 Q1401.05 73.7508 1397.45 71.8063 Q1393.88 69.8214 1391.53 65.7705 M1416.89 49.9314 Q1416.89 41.7081 1413.49 37.0496 Q1410.12 32.3505 1404.21 32.3505 Q1398.3 32.3505 1394.89 37.0496 Q1391.53 41.7081 1391.53 49.9314 Q1391.53 58.1548 1394.89 62.8538 Q1398.3 67.5124 1404.21 67.5124 Q1410.12 67.5124 1413.49 62.8538 Q1416.89 58.1548 1416.89 49.9314 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1475.79 48.0275 L1475.79 51.6733 L1441.52 51.6733 Q1442.01 59.3701 1446.14 63.421 Q1450.31 67.4314 1457.72 67.4314 Q1462.02 67.4314 1466.03 66.3781 Q1470.08 65.3249 1474.05 63.2184 L1474.05 70.267 Q1470.04 71.9684 1465.82 72.8596 Q1461.61 73.7508 1457.28 73.7508 Q1446.42 73.7508 1440.06 67.4314 Q1433.74 61.1119 1433.74 50.3365 Q1433.74 39.1965 1439.74 32.6746 Q1445.77 26.1121 1455.98 26.1121 Q1465.14 26.1121 1470.44 32.0264 Q1475.79 37.9003 1475.79 48.0275 M1468.34 45.84 Q1468.26 39.7232 1464.89 36.0774 Q1461.57 32.4315 1456.06 32.4315 Q1449.82 32.4315 1446.06 35.9558 Q1442.33 39.4801 1441.76 45.8805 L1468.34 45.84 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1520.67 28.9478 L1520.67 35.9153 Q1517.51 34.1734 1514.31 33.3227 Q1511.15 32.4315 1507.91 32.4315 Q1500.66 32.4315 1496.65 37.0496 Q1492.64 41.6271 1492.64 49.9314 Q1492.64 58.2358 1496.65 62.8538 Q1500.66 67.4314 1507.91 67.4314 Q1511.15 67.4314 1514.31 66.5807 Q1517.51 65.6895 1520.67 63.9476 L1520.67 70.8341 Q1517.55 72.2924 1514.19 73.0216 Q1510.87 73.7508 1507.1 73.7508 Q1496.85 73.7508 1490.82 67.3098 Q1484.78 60.8689 1484.78 49.9314 Q1484.78 38.832 1490.86 32.472 Q1496.98 26.1121 1507.59 26.1121 Q1511.03 26.1121 1514.31 26.8413 Q1517.6 27.5299 1520.67 28.9478 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1541.01 14.324 L1541.01 27.2059 L1556.36 27.2059 L1556.36 32.9987 L1541.01 32.9987 L1541.01 57.6282 Q1541.01 63.1779 1542.51 64.7578 Q1544.05 66.3376 1548.71 66.3376 L1556.36 66.3376 L1556.36 72.576 L1548.71 72.576 Q1540.08 72.576 1536.8 69.3758 Q1533.52 66.1351 1533.52 57.6282 L1533.52 32.9987 L1528.05 32.9987 L1528.05 27.2059 L1533.52 27.2059 L1533.52 14.324 L1541.01 14.324 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1592.46 34.1734 Q1591.2 33.4443 1589.7 33.1202 Q1588.24 32.7556 1586.46 32.7556 Q1580.14 32.7556 1576.74 36.8875 Q1573.38 40.9789 1573.38 48.6757 L1573.38 72.576 L1565.88 72.576 L1565.88 27.2059 L1573.38 27.2059 L1573.38 34.2544 Q1575.73 30.1225 1579.49 28.1376 Q1583.26 26.1121 1588.65 26.1121 Q1589.42 26.1121 1590.35 26.2337 Q1591.28 26.3147 1592.42 26.5172 L1592.46 34.1734 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1599.5 54.671 L1599.5 27.2059 L1606.96 27.2059 L1606.96 54.3874 Q1606.96 60.8284 1609.47 64.0691 Q1611.98 67.2693 1617 67.2693 Q1623.04 67.2693 1626.52 63.421 Q1630.05 59.5726 1630.05 52.9291 L1630.05 27.2059 L1637.5 27.2059 L1637.5 72.576 L1630.05 72.576 L1630.05 65.6084 Q1627.33 69.7404 1623.73 71.7658 Q1620.16 73.7508 1615.42 73.7508 Q1607.61 73.7508 1603.56 68.8897 Q1599.5 64.0286 1599.5 54.671 M1618.26 26.1121 L1618.26 26.1121 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><path clip-path="url(#clip460)" d="M1688.18 35.9153 Q1690.97 30.8922 1694.86 28.5022 Q1698.75 26.1121 1704.02 26.1121 Q1711.11 26.1121 1714.96 31.0947 Q1718.8 36.0368 1718.8 45.1919 L1718.8 72.576 L1711.31 72.576 L1711.31 45.4349 Q1711.31 38.913 1709 35.7533 Q1706.69 32.5936 1701.95 32.5936 Q1696.16 32.5936 1692.8 36.4419 Q1689.43 40.2903 1689.43 46.9338 L1689.43 72.576 L1681.94 72.576 L1681.94 45.4349 Q1681.94 38.8725 1679.63 35.7533 Q1677.32 32.5936 1672.5 32.5936 Q1666.79 32.5936 1663.43 36.4824 Q1660.07 40.3308 1660.07 46.9338 L1660.07 72.576 L1652.57 72.576 L1652.57 27.2059 L1660.07 27.2059 L1660.07 34.2544 Q1662.62 30.082 1666.18 28.0971 Q1669.75 26.1121 1674.65 26.1121 Q1679.59 26.1121 1683.03 28.6237 Q1686.52 31.1352 1688.18 35.9153 Z" fill="#000000" fill-rule="nonzero" fill-opacity="1" /><circle clip-path="url(#clip462)" cx="364.869" cy="146.608" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="399.767" cy="260.712" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="434.665" cy="301.351" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="469.563" cy="333.111" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="504.462" cy="480.589" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="539.36" cy="524.807" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="574.258" cy="549.388" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="609.156" cy="555.639" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="644.054" cy="665.373" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="678.952" cy="711.753" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="713.851" cy="744.82" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="748.749" cy="746.227" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="783.647" cy="752.239" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="818.545" cy="801.429" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="853.443" cy="804.038" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="888.341" cy="824.925" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="923.24" cy="836.849" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="958.138" cy="840.175" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="993.036" cy="869.867" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1027.93" cy="894.38" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1062.83" cy="946.898" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1097.73" cy="1000.91" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1132.63" cy="1031.77" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1167.53" cy="1037.47" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1202.42" cy="1043.96" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1237.32" cy="1097.98" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1272.22" cy="1103.65" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1307.12" cy="1140" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1342.02" cy="1157.02" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1376.92" cy="1170.05" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1411.81" cy="1171.31" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1446.71" cy="1191.87" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1481.61" cy="1192.71" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1516.51" cy="1195.7" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1551.41" cy="1203.53" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1586.3" cy="1208.32" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1621.2" cy="1231.57" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1656.1" cy="1245.27" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1691" cy="1273.73" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1725.9" cy="1284.92" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1760.8" cy="1326.01" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1795.69" cy="1341.47" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1830.59" cy="1382.31" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1865.49" cy="1388.81" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1900.39" cy="1404.69" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1935.29" cy="1414" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="1970.18" cy="1423.21" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="2005.08" cy="1438.94" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="2039.98" cy="1448.4" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
<circle clip-path="url(#clip462)" cx="2074.88" cy="1464.44" r="14.4" fill="#009af9" fill-rule="evenodd" fill-opacity="1" stroke="#000000" stroke-opacity="1" stroke-width="3.2"/>
</svg>

```

We see that some eigenvalues clearly belong to a group, and are almost degenerate.
This implies 2 things:
- there is superfluous information, if those eigenvalues are the same anyway
- poor convergence if we cut off within such a subspace

It are precisely those problems that we can solve by using symmetries.

## Symmetries

The XXZ Heisenberg hamiltonian is SU(2) symmetric and we can exploit this to greatly speed up the simulation.

It is cumbersome to construct symmetric hamiltonians, but luckily su(2) symmetric XXZ is already implemented:

````julia
H2 = heisenberg_XXX(ComplexF64, SU2Irrep, InfiniteChain(2); spin=1//2);
````

Our initial state should also be SU(2) symmetric.
It now becomes apparent why we have to use a two-site periodic state.
The physical space carries a half-integer charge and the first tensor maps the first `virtual_space ⊗ the physical_space` to the second `virtual_space`.
Half-integer virtual charges will therefore map only to integer charges, and vice versa.
The staggering thus happens on the virtual level.

An alternative constructor for the initial state is

````julia
P = Rep[SU₂](1 // 2 => 1)
V1 = Rep[SU₂](1 // 2 => 10, 3 // 2 => 5, 5 // 2 => 2)
V2 = Rep[SU₂](0 => 15, 1 => 10, 2 => 5)
state = InfiniteMPS([P, P], [V1, V2]);
````

Even though the bond dimension is higher than in the example without symmetry, convergence is reached much faster:

````julia
println(dim(V1))
println(dim(V2))
groundstate, cache, delta = find_groundstate(state, H2, VUMPS(maxiter=400, tol_galerkin=1e-12));
````

````
52
70
[ Info: vumps @iteration 1 galerkin = 0.03983470720992732
[ Info: vumps @iteration 2 galerkin = 0.005470084782380862
[ Info: vumps @iteration 3 galerkin = 0.002445233262280903
[ Info: vumps @iteration 4 galerkin = 0.0011622471138082794
[ Info: vumps @iteration 5 galerkin = 0.0008658310986604488
[ Info: vumps @iteration 6 galerkin = 0.0005925375804442109
[ Info: vumps @iteration 7 galerkin = 0.00045950630354569784
[ Info: vumps @iteration 8 galerkin = 0.0003606714233257848
[ Info: vumps @iteration 9 galerkin = 0.00027978400203657364
[ Info: vumps @iteration 10 galerkin = 0.0002138903038582846
[ Info: vumps @iteration 11 galerkin = 0.00016095028578183565
[ Info: vumps @iteration 12 galerkin = 0.00011955939029667788
[ Info: vumps @iteration 13 galerkin = 8.788722830687659e-5
[ Info: vumps @iteration 14 galerkin = 6.409848356236834e-5
[ Info: vumps @iteration 15 galerkin = 4.647715225213e-5
[ Info: vumps @iteration 16 galerkin = 3.356019093174639e-5
[ Info: vumps @iteration 17 galerkin = 2.4161948879687502e-5
[ Info: vumps @iteration 18 galerkin = 1.7359878707996212e-5
[ Info: vumps @iteration 19 galerkin = 1.245471736425661e-5
[ Info: vumps @iteration 20 galerkin = 8.926362843631308e-6
[ Info: vumps @iteration 21 galerkin = 6.392762689857463e-6
[ Info: vumps @iteration 22 galerkin = 4.575671367428788e-6
[ Info: vumps @iteration 23 galerkin = 3.2735896420757063e-6
[ Info: vumps @iteration 24 galerkin = 2.3411531011797804e-6
[ Info: vumps @iteration 25 galerkin = 1.6737593335555163e-6
[ Info: vumps @iteration 26 galerkin = 1.1962665012326152e-6
[ Info: vumps @iteration 27 galerkin = 8.547606079064306e-7
[ Info: vumps @iteration 28 galerkin = 6.105902833949259e-7
[ Info: vumps @iteration 29 galerkin = 4.360632769390177e-7
[ Info: vumps @iteration 30 galerkin = 3.1134982715431993e-7
[ Info: vumps @iteration 31 galerkin = 2.2225500530687362e-7
[ Info: vumps @iteration 32 galerkin = 1.5862177413799663e-7
[ Info: vumps @iteration 33 galerkin = 1.1318421104490093e-7
[ Info: vumps @iteration 34 galerkin = 8.074677672841449e-8
[ Info: vumps @iteration 35 galerkin = 5.7595311118623964e-8
[ Info: vumps @iteration 36 galerkin = 4.1074435552287456e-8
[ Info: vumps @iteration 37 galerkin = 2.9287650625304386e-8
[ Info: vumps @iteration 38 galerkin = 2.0880071192650158e-8
[ Info: vumps @iteration 39 galerkin = 1.4883728548727397e-8
[ Info: vumps @iteration 40 galerkin = 1.0608043223440726e-8
[ Info: vumps @iteration 41 galerkin = 7.559725155794331e-9
[ Info: vumps @iteration 42 galerkin = 5.386722742249971e-9
[ Info: vumps @iteration 43 galerkin = 3.837825139527339e-9
[ Info: vumps @iteration 44 galerkin = 2.7340492646210272e-9
[ Info: vumps @iteration 45 galerkin = 1.9475785485254777e-9
[ Info: vumps @iteration 46 galerkin = 1.387065841407004e-9
[ Info: vumps @iteration 47 galerkin = 9.87858116149877e-10
[ Info: vumps @iteration 48 galerkin = 7.036400649613467e-10
[ Info: vumps @iteration 49 galerkin = 5.010363671379773e-10
[ Info: vumps @iteration 50 galerkin = 3.5679544651306996e-10
[ Info: vumps @iteration 51 galerkin = 2.540593022259859e-10
[ Info: vumps @iteration 52 galerkin = 1.8077687745114808e-10
[ Info: vumps @iteration 53 galerkin = 1.2886877062955604e-10
[ Info: vumps @iteration 54 galerkin = 9.16729029727193e-11
[ Info: vumps @iteration 55 galerkin = 6.521747268436945e-11
[ Info: vumps @iteration 56 galerkin = 4.645808335364997e-11
[ Info: vumps @iteration 57 galerkin = 3.303917177832644e-11
[ Info: vumps @iteration 58 galerkin = 2.3534721152402163e-11
[ Info: vumps @iteration 59 galerkin = 1.67075368301289e-11
[ Info: vumps @iteration 60 galerkin = 1.1978436729163803e-11
[ Info: vumps @iteration 61 galerkin = 8.58599072353772e-12
[ Info: vumps @iteration 62 galerkin = 6.050342437344345e-12
[ Info: vumps @iteration 63 galerkin = 4.230168489330012e-12
[ Info: vumps @iteration 64 galerkin = 3.0209653791804435e-12
[ Info: vumps @iteration 65 galerkin = 2.2943563087643904e-12
[ Info: vumps @iteration 66 galerkin = 1.5358853707810685e-12
[ Info: vumps @iteration 67 galerkin = 1.133541258426264e-12
[ Info: vumps @iteration 68 galerkin = 7.982572192348798e-13

````

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

